# Getting Started with Tester

Testing various
api
features


## Building

You must have Python ```2 >=2.7.9``` or Python ```3 >=3.4``` installed on your system to install and run this SDK. This SDK package depends on other Python packages like nose, jsonpickle etc. These dependencies are defined in the ```requirements.txt``` file that comes with the SDK.To resolve these dependencies, you can use the PIP Dependency manager. Install it by following steps at [https://pip.pypa.io/en/stable/installing/](https://pip.pypa.io/en/stable/installing/).

Python and PIP executables should be defined in your PATH. Open command prompt and type ```pip --version```. This should display the version of the PIP Dependency Manager installed if your installation was successful and the paths are properly defined.

* Using command line, navigate to the directory containing the generated files (including ```requirements.txt```) for the SDK.
* Run the command ```pip install -r requirements.txt```. This should install all the required dependencies.

![Building SDK - Step 1](https://apidocs.io/illustration/python?workspaceFolder=Tester-Python&step=installDependencies)

## Installation

The following section explains how to use the tester library in a new project.

### 1. Open Project in an IDE

Open up a Python IDE like PyCharm. The basic workflow presented here is also applicable if you prefer using a different editor or IDE.

![Open project in PyCharm - Step 1](https://apidocs.io/illustration/python?workspaceFolder=Tester-Python&step=pyCharm)

Click on `Open` in PyCharm to browse to your generated SDK directory and then click `OK`.

![Open project in PyCharm - Step 2](https://apidocs.io/illustration/python?workspaceFolder=Tester-Python&step=openProject0)

The project files will be displayed in the side bar as follows:

![Open project in PyCharm - Step 3](https://apidocs.io/illustration/python?workspaceFolder=Tester-Python&projectName=tester&step=openProject1)

### 2. Add a new Test Project

Create a new directory by right clicking on the solution name as shown below:

![Add a new project in PyCharm - Step 1](https://apidocs.io/illustration/python?workspaceFolder=Tester-Python&projectName=tester&step=createDirectory)

Name the directory as "test".

![Add a new project in PyCharm - Step 2](https://apidocs.io/illustration/python?workspaceFolder=Tester-Python&step=nameDirectory)

Add a python file to this project.

![Add a new project in PyCharm - Step 3](https://apidocs.io/illustration/python?workspaceFolder=Tester-Python&projectName=tester&step=createFile)

Name it "testSDK".

![Add a new project in PyCharm - Step 4](https://apidocs.io/illustration/python?workspaceFolder=Tester-Python&projectName=tester&step=nameFile)

In your python file you will be required to import the generated python library using the following code lines

```python
from tester.tester_client import TesterClient
```

![Add a new project in PyCharm - Step 5](https://apidocs.io/illustration/python?workspaceFolder=Tester-Python&projectName=tester&libraryName=tester.tester_client&className=TesterClient&step=projectFiles)

After this you can write code to instantiate an API client object, get a controller object and  make API calls. Sample code is given in the subsequent sections.

### 3. Run the Test Project

To run the file within your test project, right click on your Python file inside your Test project and click on `Run`

![Run Test Project - Step 1](https://apidocs.io/illustration/python?workspaceFolder=Tester-Python&projectName=tester&libraryName=tester.tester_client&className=TesterClient&step=runProject)

## Testing

You can test the generated SDK and the server with automatically generated test cases. `unittest` is used as the testing framework and `nose` is used as the test runner. You can run the tests as follows:

1. From terminal/cmd navigate to the root directory of the SDK.
  2. Invoke ```pip install -r test-requirements.txt``` 
  3. Invoke ```nosetests```

## Usage

To initialize the API client, the following parameters need to be passed.

| Parameter | Type | Description |
|  --- | --- | --- |
| `port` | `string` | *Default*: `'80'` |
| `suites` | `SuiteCode` | *Default*: `1` |

The API client can be initialized using a Configuration object as following.

```python

client = TesterClient(
    # Set the environment
    environment = Environment.TESTING,

    # Set configuration parameters
    port = '80',
    suites = SuiteCode.HEARTS,)
```

## Environments

The SDK can be configured to use a different environment for making API calls. Available environments are:

| Name | Value | Description |
|  --- | --- | --- |
| production | `PRODUCTION` |  |
| testing | `TESTING` | **Default**  |

## Authorization

This API does not require authentication.

## API Errors

Here is the list of errors that the API might throw.

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 400 | 400 Global | `APIException` |
| 402 | 402 Global | `APIException` |
| 403 | 403 Global | `APIException` |
| 404 | 404 Global | `APIException` |
| 412 | Precondition Failed | [`NestedModelException`](#nestedmodelexception) |
| 450 | caught global exception | [`CustomErrorResponseException`](#customerrorresponseexception) |
| 452 | global exception with string | [`ExceptionWithStringException`](#exceptionwithstringexception) |
| 453 | boolean in global exception | [`ExceptionWithBooleanException`](#exceptionwithbooleanexception) |
| 454 | dynamic in global exception | [`ExceptionWithDynamicException`](#exceptionwithdynamicexception) |
| 455 | uuid in global exception | [`ExceptionWithUUIDException`](#exceptionwithuuidexception) |
| 456 | date in global exception | [`ExceptionWithDateException`](#exceptionwithdateexception) |
| 457 | number in global  exception | [`ExceptionWithNumberException`](#exceptionwithnumberexception) |
| 458 | long in global exception | [`ExceptionWithLongException`](#exceptionwithlongexception) |
| 459 | precision in global  exception | [`ExceptionWithPrecisionException`](#exceptionwithprecisionexception) |
| 460 | rfc3339 in global exception | [`ExceptionWithRfc3339DateTimeException`](#exceptionwithrfc3339datetimeexception) |
| 461 | unix time stamp in global exception | [`UnixTimeStampException`](#unixtimestampexception) |
| 462 | rfc1123 in global exception | [`Rfc1123Exception`](#rfc1123exception) |
| 463 | boolean in model as global exception | [`SendBooleanInModelAsException`](#sendbooleaninmodelasexception) |
| 464 | rfc3339 in model as global exception | [`SendRfc3339InModelAsException`](#sendrfc3339inmodelasexception) |
| 465 | rfc1123 in model as global exception | [`SendRfc1123InModelAsException`](#sendrfc1123inmodelasexception) |
| 466 | unix time stamp in model as global exception | [`SendUnixTimeStampInModelAsException`](#sendunixtimestampinmodelasexception) |
| 467 | send date in model as global exception | [`SendDateInModelAsException`](#senddateinmodelasexception) |
| 468 | send dynamic in model as global exception | [`SendDynamicInModelAsException`](#senddynamicinmodelasexception) |
| 469 | send string in model as global exception | [`SendStringInModelAsException`](#sendstringinmodelasexception) |
| 470 | send long in model as global exception | [`SendLongInModelAsException`](#sendlonginmodelasexception) |
| 471 | send number in model as global exception | [`SendNumberInModelAsException`](#sendnumberinmodelasexception) |
| 472 | send precision in model as global exception | [`SendPrecisionInModelAsException`](#sendprecisioninmodelasexception) |
| 473 | send uuid in model as global exception | [`SendUuidInModelAsException`](#senduuidinmodelasexception) |
| 500 | 500 Global | [`GlobalTestException`](#globaltestexception) |
| Default | Invalid response. | [`GlobalTestException`](#globaltestexception) |

## API Reference

### List of APIs

* [Response Types](#responsetypescontroller)
* [Form Params](#formparamscontroller)
* [Body Params](#bodyparamscontroller)
* [Error Codes](#errorcodescontroller)
* [Query Param](#queryparamcontroller)
* [Echo](#echocontroller)
* [Header](#headercontroller)
* [Template Params](#templateparamscontroller)
* [Query Params](#queryparamscontroller)

### `ResponseTypesController`

#### Overview

##### Get instance

An instance of the `ResponseTypesController` class can be accessed from the API Client.

```
response_types_controller = client.response_types
```

#### get_date_array

```python
def get_date_array(self)
```

##### Response Type

`List of date`

##### Example Usage

```python


result = response_types_controller.get_date_array()
```

#### get_date

```python
def get_date(self)
```

##### Response Type

`date`

##### Example Usage

```python

result = response_types_controller.get_date()
```

#### return_company_model

```python
def return_company_model(self)
```

##### Response Type

[`Company`](#company)

##### Example Usage

```python

result = response_types_controller.return_company_model()
```

##### Example Response *(as JSON)*

```json
{
  "company name": "APIMatic",
  "address": "nust",
  "cell number": "090078601"
}
```

#### return_boss_model

```python
def return_boss_model(self)
```

##### Response Type

[`BossCompany`](#bosscompany)

##### Example Usage

```python

result = response_types_controller.return_boss_model()
```

##### Example Response *(as JSON)*

```json
{
  "company name": "APIMatic",
  "address": "nust",
  "cell number": "090078601",
  "first name": "Adeel",
  "last name": "Ali",
  "address_boss": "nust"
}
```

#### return_employee_model

```python
def return_employee_model(self)
```

##### Response Type

[`EmployeeComp`](#employeecomp)

##### Example Usage

```python

result = response_types_controller.return_employee_model()
```

##### Example Response *(as JSON)*

```json
{
  "company name": "APIMatic",
  "address": "nust",
  "cell number": "090078601",
  "first name": "Nauman",
  "last name": "Ali",
  "id": "123456"
}
```

#### return_developer_model

```python
def return_developer_model(self)
```

##### Response Type

[`Developer`](#developer)

##### Example Usage

```python

result = response_types_controller.return_developer_model()
```

##### Example Response *(as JSON)*

```json
{
  "company name": "APIMatic",
  "address": "nust",
  "cell number": "090078601",
  "first name": "Nauman",
  "last name": "Ali",
  "id": "123456",
  "team": "CORE",
  "designation": "Manager",
  "role": "Team Lead"
}
```

#### return_tester_model

```python
def return_tester_model(self)
```

##### Response Type

[`SoftwareTester`](#softwaretester)

##### Example Usage

```python

result = response_types_controller.return_tester_model()
```

##### Example Response *(as JSON)*

```json
{
  "company name": "APIMatic",
  "address": "nust",
  "cell number": "090078601",
  "first name": "Muhammad",
  "last name": "Farhan",
  "id": "123456",
  "team": "Testing",
  "designation": "Tester",
  "role": "Testing"
}
```

#### return_complex_1_object

```python
def return_complex_1_object(self)
```

##### Response Type

[`Complex1`](#complex1)

##### Example Usage

```python

result = response_types_controller.return_complex_1_object()
```

##### Example Response *(as JSON)*

```json
{
  "medications": [
    {
      "aceInhibitors": [
        {
          "name": "lisinopril",
          "strength": "10 mg Tab",
          "dose": "1 tab",
          "route": "PO",
          "sig": "daily",
          "pillCount": "#90",
          "refills": "Refill 3"
        }
      ],
      "antianginal": [
        {
          "name": "nitroglycerin",
          "strength": "0.4 mg Sublingual Tab",
          "dose": "1 tab",
          "route": "SL",
          "sig": "q15min PRN",
          "pillCount": "#30",
          "refills": "Refill 1"
        }
      ],
      "anticoagulants": [
        {
          "name": "warfarin sodium",
          "strength": "3 mg Tab",
          "dose": "1 tab",
          "route": "PO",
          "sig": "daily",
          "pillCount": "#90",
          "refills": "Refill 3"
        }
      ],
      "betaBlocker": [
        {
          "name": "metoprolol tartrate",
          "strength": "25 mg Tab",
          "dose": "1 tab",
          "route": "PO",
          "sig": "daily",
          "pillCount": "#90",
          "refills": "Refill 3"
        }
      ],
      "diuretic": [
        {
          "name": "furosemide",
          "strength": "40 mg Tab",
          "dose": "1 tab",
          "route": "PO",
          "sig": "daily",
          "pillCount": "#90",
          "refills": "Refill 3"
        }
      ],
      "mineral": [
        {
          "name": "potassium chloride ER",
          "strength": "10 mEq Tab",
          "dose": "1 tab",
          "route": "PO",
          "sig": "daily",
          "pillCount": "#90",
          "refills": "Refill 3"
        }
      ]
    }
  ],
  "labs": [
    {
      "name": "Arterial Blood Gas",
      "time": "Today",
      "location": "Main Hospital Lab"
    },
    {
      "name": "BMP",
      "time": "Today",
      "location": "Primary Care Clinic"
    },
    {
      "name": "BNP",
      "time": "3 Weeks",
      "location": "Primary Care Clinic"
    },
    {
      "name": "BUN",
      "time": "1 Year",
      "location": "Primary Care Clinic"
    },
    {
      "name": "Cardiac Enzymes",
      "time": "Today",
      "location": "Primary Care Clinic"
    },
    {
      "name": "CBC",
      "time": "1 Year",
      "location": "Primary Care Clinic"
    },
    {
      "name": "Creatinine",
      "time": "1 Year",
      "location": "Main Hospital Lab"
    },
    {
      "name": "Electrolyte Panel",
      "time": "1 Year",
      "location": "Primary Care Clinic"
    },
    {
      "name": "Glucose",
      "time": "1 Year",
      "location": "Main Hospital Lab"
    },
    {
      "name": "PT/INR",
      "time": "3 Weeks",
      "location": "Primary Care Clinic"
    },
    {
      "name": "PTT",
      "time": "3 Weeks",
      "location": "Coumadin Clinic"
    },
    {
      "name": "TSH",
      "time": "1 Year",
      "location": "Primary Care Clinic"
    }
  ],
  "imaging": [
    {
      "name": "Chest X-Ray",
      "time": "Today",
      "location": "Main Hospital Radiology"
    },
    {
      "name": "Chest X-Ray",
      "time": "Today",
      "location": "Main Hospital Radiology"
    },
    {
      "name": "Chest X-Ray",
      "time": "Today",
      "location": "Main Hospital Radiology"
    }
  ]
}
```

#### return_response_with_enums

```python
def return_response_with_enums(self)
```

##### Response Type

[`ResponseWithEnum`](#responsewithenum)

##### Example Usage

```python

result = response_types_controller.return_response_with_enums()
```

##### Example Response *(as JSON)*

```json
{
  "paramFormat": "Template",
  "optional": false,
  "type": "Long",
  "constant": false,
  "isArray": false,
  "isStream": false,
  "isAttribute": false,
  "isMap": false,
  "attributes": {
    "exclusiveMaximum": false,
    "exclusiveMinimum": false,
    "id": "5a9fcb01caacc310dc6bab51"
  },
  "nullable": false,
  "id": "5a9fcb01caacc310dc6bab50",
  "name": "petId",
  "description": "ID of pet to update"
}
```

#### return_complex_2_object

```python
def return_complex_2_object(self)
```

##### Response Type

[`Complex2`](#complex2)

##### Example Usage

```python

result = response_types_controller.return_complex_2_object()
```

##### Example Response *(as JSON)*

```json
{
  "glossary": {
    "title": "example glossary",
    "GlossDiv": {
      "title": "S",
      "GlossList": {
        "GlossEntry": {
          "ID": "SGML",
          "SortAs": "SGML",
          "GlossTerm": "Standard Generalized Markup Language",
          "Acronym": "SGML",
          "Abbrev": "ISO 8879:1986",
          "GlossDef": {
            "para": "A meta-markup language, used to create markup languages such as DocBook.",
            "GlossSeeAlso": [
              "GML",
              "XML"
            ]
          },
          "GlossSee": "markup"
        }
      }
    }
  }
}
```

#### return_complex_3_object

```python
def return_complex_3_object(self)
```

##### Response Type

[`Complex3`](#complex3)

##### Example Usage

```python

result = response_types_controller.return_complex_3_object()
```

##### Example Response *(as JSON)*

```json
{
  "documentId": "099cceda-38a8-4b01-87b9-a8f2007675d6",
  "signers": [
    {
      "id": "1bef97d1-0704-4eb2-a490-a8f2007675db",
      "url": "https://sign-test.idfy.io/start?jwt=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzM4NCJ9. .Dyy2RSeR6dmU8qxOEi-2gEX3Gg7wry6JhkZIWOuADDdu5jJWidQLcxfJn_qAHNpb",
      "links": [],
      "externalSignerId": "uoiahsd321982983jhrmnec2wsadm32",
      "redirectSettings": {
        "redirectMode": "donot_redirect"
      },
      "signatureType": {
        "mechanism": "pkisignature",
        "onEacceptUseHandWrittenSignature": false
      },
      "ui": {
        "dialogs": {
          "before": {
            "useCheckBox": false,
            "title": "Info",
            "message": "Please read the contract on the next pages carefully. Pay some extra attention to paragraph 5."
          }
        },
        "language": "EN",
        "styling": {
          "colorTheme": "Pink",
          "spinner": "Cubes"
        }
      },
      "tags": [],
      "order": 0,
      "required": false
    }
  ],
  "status": {
    "documentStatus": "unsigned",
    "completedPackages": [],
    "attachmentPackages": {}
  },
  "title": "Test document",
  "description": "This is an important document",
  "externalId": "ae7b9ca7-3839-4e0d-a070-9f14bffbbf55",
  "dataToSign": {
    "fileName": "sample.txt",
    "convertToPDF": false
  },
  "contactDetails": {
    "email": "test@test.com",
    "url": "https://idfy.io"
  },
  "advanced": {
    "tags": [
      "develop",
      "fun_with_documents"
    ],
    "attachments": 0,
    "requiredSignatures": 0,
    "getSocialSecurityNumber": false,
    "timeToLive": {
      "deadline": "2018-06-29T14:57:25Z",
      "deleteAfterHours": 1
    }
  }
}
```

#### get_long

```python
def get_long(self)
```

##### Response Type

`long|int`

##### Example Usage

```python

result = response_types_controller.get_long()
```

#### get_model

```python
def get_model(self)
```

##### Response Type

[`Person`](#person)

##### Example Usage

```python

result = response_types_controller.get_model()
```

#### get_string_enum_array

```python
def get_string_enum_array(self)
```

##### Response Type

[`List of Days`](#days)

##### Example Usage

```python


result = response_types_controller.get_string_enum_array()
```

#### get_string_enum

```python
def get_string_enum(self)
```

##### Response Type

[`Days`](#days)

##### Example Usage

```python


result = response_types_controller.get_string_enum()
```

#### get_model_array

```python
def get_model_array(self)
```

##### Response Type

[`List of Person`](#person)

##### Example Usage

```python


result = response_types_controller.get_model_array()
```

#### get_int_enum

```python
def get_int_enum(self)
```

##### Response Type

[`SuiteCode`](#suitecode)

##### Example Usage

```python


result = response_types_controller.get_int_enum()
```

#### get_int_enum_array

```python
def get_int_enum_array(self)
```

##### Response Type

[`List of SuiteCode`](#suitecode)

##### Example Usage

```python


result = response_types_controller.get_int_enum_array()
```

#### get_precision

```python
def get_precision(self)
```

##### Response Type

`float`

##### Example Usage

```python

result = response_types_controller.get_precision()
```

#### get_binary

gets a binary object

```python
def get_binary(self)
```

##### Response Type

`binary`

##### Example Usage

```python

result = response_types_controller.get_binary()
```

#### get_integer

Gets a integer response

```python
def get_integer(self)
```

##### Response Type

`int`

##### Example Usage

```python

result = response_types_controller.get_integer()
```

#### get_integer_array

Get an array of integers.

```python
def get_integer_array(self)
```

##### Response Type

`List of int`

##### Example Usage

```python


result = response_types_controller.get_integer_array()
```

#### get_dynamic

```python
def get_dynamic(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = response_types_controller.get_dynamic()
```

#### get_dynamic_array

```python
def get_dynamic_array(self)
```

##### Response Type

`mixed`

##### Example Usage

```python


result = response_types_controller.get_dynamic_array()
```

#### get_3339_datetime

```python
def get_3339_datetime(self)
```

##### Response Type

`datetime`

##### Example Usage

```python

result = response_types_controller.get_3339_datetime()
```

#### get_3339_datetime_array

```python
def get_3339_datetime_array(self)
```

##### Response Type

`List of datetime`

##### Example Usage

```python


result = response_types_controller.get_3339_datetime_array()
```

#### get_boolean

```python
def get_boolean(self)
```

##### Response Type

`bool`

##### Example Usage

```python

result = response_types_controller.get_boolean()
```

#### get_boolean_array

```python
def get_boolean_array(self)
```

##### Response Type

`List of bool`

##### Example Usage

```python


result = response_types_controller.get_boolean_array()
```

#### get_headers

```python
def get_headers(self)
```

##### Response Type

`void`

##### Example Usage

```python

result = response_types_controller.get_headers()
```

#### get_1123_date_time

```python
def get_1123_date_time(self)
```

##### Response Type

`datetime`

##### Example Usage

```python

result = response_types_controller.get_1123_date_time()
```

#### get_unix_date_time

```python
def get_unix_date_time(self)
```

##### Response Type

`datetime`

##### Example Usage

```python

result = response_types_controller.get_unix_date_time()
```

#### get_1123_date_time_array

```python
def get_1123_date_time_array(self)
```

##### Response Type

`List of datetime`

##### Example Usage

```python


result = response_types_controller.get_1123_date_time_array()
```

#### get_unix_date_time_array

```python
def get_unix_date_time_array(self)
```

##### Response Type

`List of datetime`

##### Example Usage

```python


result = response_types_controller.get_unix_date_time_array()
```

#### get_content_type_headers

```python
def get_content_type_headers(self)
```

##### Response Type

`void`

##### Example Usage

```python

result = response_types_controller.get_content_type_headers()
```

### `FormParamsController`

#### Overview

##### Get instance

An instance of the `FormParamsController` class can be accessed from the API Client.

```
form_params_controller = client.form_params
```

#### send_delete_form

```python
def send_delete_form(self,
                    body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`DeleteBody`](#deletebody) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = DeleteBody()()
body.name = 'name6'
body.field = 'field0'

result = form_params_controller.send_delete_form(body)
```

#### send_delete_multipart

```python
def send_delete_multipart(self,
                         file)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `file` | `string` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

file = open('dummy_file', 'r')

result = form_params_controller.send_delete_multipart(file)
```

#### send_date_array

```python
def send_date_array(self,
                   dates)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `dates` | `List of date` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

dates = [dateutil.parser.parse('2016-03-13').date(), dateutil.parser.parse('2016-03-13').date()]

result = form_params_controller.send_date_array(dates)
```

#### send_date

```python
def send_date(self,
             date)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date` | `date` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

date = dateutil.parser.parse('2016-03-13').date()

result = form_params_controller.send_date(date)
```

#### send_unix_date_time

```python
def send_unix_date_time(self,
                       datetime)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetime` | `datetime` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetime = dt.datetime.utcfromtimestamp(1480809600)

result = form_params_controller.send_unix_date_time(datetime)
```

#### send_rfc_1123_date_time

```python
def send_rfc_1123_date_time(self,
                           datetime)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetime` | `datetime` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetime = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime

result = form_params_controller.send_rfc_1123_date_time(datetime)
```

#### send_rfc_3339_date_time

```python
def send_rfc_3339_date_time(self,
                           datetime)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetime` | `datetime` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')

result = form_params_controller.send_rfc_3339_date_time(datetime)
```

#### send_unix_date_time_array

```python
def send_unix_date_time_array(self,
                             datetimes)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetimes` | `List of datetime` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetimes = [dt.datetime.utcfromtimestamp(1480809600), dt.datetime.utcfromtimestamp(1480809600), dt.datetime.utcfromtimestamp(1480809600)]

result = form_params_controller.send_unix_date_time_array(datetimes)
```

#### send_rfc_1123_date_time_array

```python
def send_rfc_1123_date_time_array(self,
                                 datetimes)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetimes` | `List of datetime` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetimes = [APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime, APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime, APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime]

result = form_params_controller.send_rfc_1123_date_time_array(datetimes)
```

#### send_long

```python
def send_long(self,
             value)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `long|int` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

value = 64

result = form_params_controller.send_long(value)
```

#### send_integer_array

```python
def send_integer_array(self,
                      integers)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `integers` | `List of int` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

integers = [45, 46, 47]

result = form_params_controller.send_integer_array(integers)
```

#### send_string_array

```python
def send_string_array(self,
                     strings)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `strings` | `List of string` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

strings = ['strings5']

result = form_params_controller.send_string_array(strings)
```

#### allow_dynamic_form_fields

```python
def allow_dynamic_form_fields(self,
                             name,
                             _optional_form_parameters=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `name` | `string` | Form, Required | - |
| `_optional_form_parameters` | `array` | Optional | Pass additional field parameters. |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

name = 'name0'
_optional_form_parameters = {'key0' : 'additionalFieldParams9' } 

result = form_params_controller.allow_dynamic_form_fields(name, _optional_form_parameters)
```

#### send_model

```python
def send_model(self,
              model)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `model` | [`Employee`](#employee) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

model = Employee()()
model.department = 'department8'
model.dependents = []

model.dependents.append(Person())
model.dependents[0].address = 'address5'
model.dependents[0].age = 237
model.dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
model.dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
model.dependents[0].name = 'name9'
model.dependents[0].uid = 'uid9'

model.hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
model.joining_day = Days.TUESDAY
model.salary = 240
model.working_days = [Days.THURSDAY, Days.WEDNESDAY_, Days.TUESDAY]
model.address = 'address8'
model.age = 186
model.birthday = dateutil.parser.parse('2016-03-13').date()
model.birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
model.name = 'name2'
model.uid = 'uid2'

result = form_params_controller.send_model(model)
```

#### send_model_array

```python
def send_model_array(self,
                    models)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `models` | [`List of Employee`](#employee) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

models = []

models.append(Employee())
models[0].department = 'department6'
models[0].dependents = []

models[0].dependents.append(Person())
models[0].dependents[0].address = 'address9'
models[0].dependents[0].age = 49
models[0].dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[0].name = 'name3'
models[0].dependents[0].uid = 'uid3'

models[0].dependents.append(Person())
models[0].dependents[1].address = 'address0'
models[0].dependents[1].age = 50
models[0].dependents[1].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[1].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[1].name = 'name4'
models[0].dependents[1].uid = 'uid4'

models[0].dependents.append(Person())
models[0].dependents[2].address = 'address1'
models[0].dependents[2].age = 51
models[0].dependents[2].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[2].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[2].name = 'name5'
models[0].dependents[2].uid = 'uid5'

models[0].hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
models[0].joining_day = Days.WEDNESDAY_
models[0].salary = 84
models[0].working_days = [Days.SUNDAY]
models[0].address = 'address2'
models[0].age = 254
models[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].name = 'name6'
models[0].uid = 'uid6'

models.append(Employee())
models[1].department = 'department7'
models[1].dependents = []

models[1].dependents.append(Person())
models[1].dependents[0].address = 'address0'
models[1].dependents[0].age = 50
models[1].dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[1].dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[1].dependents[0].name = 'name4'
models[1].dependents[0].uid = 'uid4'

models[1].hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
models[1].joining_day = Days.THURSDAY
models[1].salary = 85
models[1].working_days = [Days.MONDAY, Days.TUESDAY]
models[1].address = 'address3'
models[1].age = 255
models[1].birthday = dateutil.parser.parse('2016-03-13').date()
models[1].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[1].name = 'name7'
models[1].uid = 'uid7'


result = form_params_controller.send_model_array(models)
```

#### send_file

```python
def send_file(self,
             file)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `file` | `string` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

file = open('dummy_file', 'r')

result = form_params_controller.send_file(file)
```

#### send_multiple_files

```python
def send_multiple_files(self,
                       file,
                       file_1)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `file` | `string` | Form, Required | - |
| `file_1` | `string` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

file = open('dummy_file', 'r')
file_1 = open('dummy_file', 'r')

result = form_params_controller.send_multiple_files(file, file_1)
```

#### send_string

```python
def send_string(self,
               value)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `string` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

value = 'value2'

result = form_params_controller.send_string(value)
```

#### send_rfc_3339_date_time_array

```python
def send_rfc_3339_date_time_array(self,
                                 datetimes)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetimes` | `List of datetime` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetimes = [dateutil.parser.parse('2016-03-13T12:52:32.123Z'), dateutil.parser.parse('2016-03-13T12:52:32.123Z'), dateutil.parser.parse('2016-03-13T12:52:32.123Z')]

result = form_params_controller.send_rfc_3339_date_time_array(datetimes)
```

#### send_mixed_array

Send a variety for form params. Returns file count and body params

```python
def send_mixed_array(self,
                    options=dict())
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `file` | `string` | Form, Required | - |
| `integers` | `List of int` | Form, Required | - |
| `models` | [`List of Employee`](#employee) | Form, Required | - |
| `strings` | `List of string` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

collect = {}
file = open('dummy_file', 'r')
collect['file'] = file

integers = [45, 46, 47]
collect['integers'] = integers

models = []

models.append(Employee())
models[0].department = 'department6'
models[0].dependents = []

models[0].dependents.append(Person())
models[0].dependents[0].address = 'address9'
models[0].dependents[0].age = 49
models[0].dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[0].name = 'name3'
models[0].dependents[0].uid = 'uid3'

models[0].dependents.append(Person())
models[0].dependents[1].address = 'address0'
models[0].dependents[1].age = 50
models[0].dependents[1].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[1].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[1].name = 'name4'
models[0].dependents[1].uid = 'uid4'

models[0].dependents.append(Person())
models[0].dependents[2].address = 'address1'
models[0].dependents[2].age = 51
models[0].dependents[2].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[2].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[2].name = 'name5'
models[0].dependents[2].uid = 'uid5'

models[0].hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
models[0].joining_day = Days.WEDNESDAY_
models[0].salary = 84
models[0].working_days = [Days.SUNDAY]
models[0].address = 'address2'
models[0].age = 254
models[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].name = 'name6'
models[0].uid = 'uid6'

models.append(Employee())
models[1].department = 'department7'
models[1].dependents = []

models[1].dependents.append(Person())
models[1].dependents[0].address = 'address0'
models[1].dependents[0].age = 50
models[1].dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[1].dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[1].dependents[0].name = 'name4'
models[1].dependents[0].uid = 'uid4'

models[1].hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
models[1].joining_day = Days.THURSDAY
models[1].salary = 85
models[1].working_days = [Days.MONDAY, Days.TUESDAY]
models[1].address = 'address3'
models[1].age = 255
models[1].birthday = dateutil.parser.parse('2016-03-13').date()
models[1].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[1].name = 'name7'
models[1].uid = 'uid7'

collect['models'] = models

strings = ['strings5']
collect['strings'] = strings

result = form_params_controller.send_mixed_array(collect)
```

#### update_model_with_form

```python
def update_model_with_form(self,
                          model)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `model` | [`Employee`](#employee) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

model = Employee()()
model.department = 'department8'
model.dependents = []

model.dependents.append(Person())
model.dependents[0].address = 'address5'
model.dependents[0].age = 237
model.dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
model.dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
model.dependents[0].name = 'name9'
model.dependents[0].uid = 'uid9'

model.hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
model.joining_day = Days.TUESDAY
model.salary = 240
model.working_days = [Days.THURSDAY, Days.WEDNESDAY_, Days.TUESDAY]
model.address = 'address8'
model.age = 186
model.birthday = dateutil.parser.parse('2016-03-13').date()
model.birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
model.name = 'name2'
model.uid = 'uid2'

result = form_params_controller.update_model_with_form(model)
```

#### send_delete_form_1

```python
def send_delete_form_1(self,
                      model)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `model` | [`Employee`](#employee) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

model = Employee()()
model.department = 'department8'
model.dependents = []

model.dependents.append(Person())
model.dependents[0].address = 'address5'
model.dependents[0].age = 237
model.dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
model.dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
model.dependents[0].name = 'name9'
model.dependents[0].uid = 'uid9'

model.hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
model.joining_day = Days.TUESDAY
model.salary = 240
model.working_days = [Days.THURSDAY, Days.WEDNESDAY_, Days.TUESDAY]
model.address = 'address8'
model.age = 186
model.birthday = dateutil.parser.parse('2016-03-13').date()
model.birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
model.name = 'name2'
model.uid = 'uid2'

result = form_params_controller.send_delete_form_1(model)
```

#### send_delete_form_with_model_array

```python
def send_delete_form_with_model_array(self,
                                     models)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `models` | [`List of Employee`](#employee) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

models = []

models.append(Employee())
models[0].department = 'department6'
models[0].dependents = []

models[0].dependents.append(Person())
models[0].dependents[0].address = 'address9'
models[0].dependents[0].age = 49
models[0].dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[0].name = 'name3'
models[0].dependents[0].uid = 'uid3'

models[0].dependents.append(Person())
models[0].dependents[1].address = 'address0'
models[0].dependents[1].age = 50
models[0].dependents[1].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[1].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[1].name = 'name4'
models[0].dependents[1].uid = 'uid4'

models[0].dependents.append(Person())
models[0].dependents[2].address = 'address1'
models[0].dependents[2].age = 51
models[0].dependents[2].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[2].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[2].name = 'name5'
models[0].dependents[2].uid = 'uid5'

models[0].hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
models[0].joining_day = Days.WEDNESDAY_
models[0].salary = 84
models[0].working_days = [Days.SUNDAY]
models[0].address = 'address2'
models[0].age = 254
models[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].name = 'name6'
models[0].uid = 'uid6'

models.append(Employee())
models[1].department = 'department7'
models[1].dependents = []

models[1].dependents.append(Person())
models[1].dependents[0].address = 'address0'
models[1].dependents[0].age = 50
models[1].dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[1].dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[1].dependents[0].name = 'name4'
models[1].dependents[0].uid = 'uid4'

models[1].hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
models[1].joining_day = Days.THURSDAY
models[1].salary = 85
models[1].working_days = [Days.MONDAY, Days.TUESDAY]
models[1].address = 'address3'
models[1].age = 255
models[1].birthday = dateutil.parser.parse('2016-03-13').date()
models[1].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[1].name = 'name7'
models[1].uid = 'uid7'


result = form_params_controller.send_delete_form_with_model_array(models)
```

#### update_model_array_with_form

```python
def update_model_array_with_form(self,
                                models)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `models` | [`List of Employee`](#employee) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

models = []

models.append(Employee())
models[0].department = 'department6'
models[0].dependents = []

models[0].dependents.append(Person())
models[0].dependents[0].address = 'address9'
models[0].dependents[0].age = 49
models[0].dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[0].name = 'name3'
models[0].dependents[0].uid = 'uid3'

models[0].dependents.append(Person())
models[0].dependents[1].address = 'address0'
models[0].dependents[1].age = 50
models[0].dependents[1].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[1].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[1].name = 'name4'
models[0].dependents[1].uid = 'uid4'

models[0].dependents.append(Person())
models[0].dependents[2].address = 'address1'
models[0].dependents[2].age = 51
models[0].dependents[2].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[2].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[2].name = 'name5'
models[0].dependents[2].uid = 'uid5'

models[0].hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
models[0].joining_day = Days.WEDNESDAY_
models[0].salary = 84
models[0].working_days = [Days.SUNDAY]
models[0].address = 'address2'
models[0].age = 254
models[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].name = 'name6'
models[0].uid = 'uid6'

models.append(Employee())
models[1].department = 'department7'
models[1].dependents = []

models[1].dependents.append(Person())
models[1].dependents[0].address = 'address0'
models[1].dependents[0].age = 50
models[1].dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[1].dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[1].dependents[0].name = 'name4'
models[1].dependents[0].uid = 'uid4'

models[1].hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
models[1].joining_day = Days.THURSDAY
models[1].salary = 85
models[1].working_days = [Days.MONDAY, Days.TUESDAY]
models[1].address = 'address3'
models[1].age = 255
models[1].birthday = dateutil.parser.parse('2016-03-13').date()
models[1].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[1].name = 'name7'
models[1].uid = 'uid7'


result = form_params_controller.update_model_array_with_form(models)
```

#### update_string_with_form

```python
def update_string_with_form(self,
                           value)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `string` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

value = 'value2'

result = form_params_controller.update_string_with_form(value)
```

#### update_string_array_with_form

```python
def update_string_array_with_form(self,
                                 strings)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `strings` | `List of string` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

strings = ['strings5']

result = form_params_controller.update_string_array_with_form(strings)
```

#### send_integer_enum_array

```python
def send_integer_enum_array(self,
                           suites)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `suites` | [`List of SuiteCode`](#suitecode) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

suites = [SuiteCode.HEARTS, SuiteCode.SPADES, SuiteCode.CLUBS]

result = form_params_controller.send_integer_enum_array(suites)
```

#### send_string_enum_array

```python
def send_string_enum_array(self,
                          days)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `days` | [`List of Days`](#days) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

days = [Days.SUNDAY, Days.MONDAY, Days.TUESDAY]

result = form_params_controller.send_string_enum_array(days)
```

#### send_string_in_form_with_new_line

```python
def send_string_in_form_with_new_line(self,
                                     body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`TestNstringEncoding`](#testnstringencoding) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = TestNstringEncoding()()
body.field = 'field0'
body.name = 'name6'

result = form_params_controller.send_string_in_form_with_new_line(body)
```

#### send_string_in_form_with_r

```python
def send_string_in_form_with_r(self,
                              body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`TestRstringEncoding`](#testrstringencoding) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = TestRstringEncoding()()
body.field = 'field0'
body.name = 'name6'

result = form_params_controller.send_string_in_form_with_r(body)
```

#### send_string_in_form_with_r_n

```python
def send_string_in_form_with_r_n(self,
                                body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`TestRNstringEncoding`](#testrnstringencoding) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = TestRNstringEncoding()()
body.field = 'field0'
body.name = 'name6'

result = form_params_controller.send_string_in_form_with_r_n(body)
```

#### send_optional_unix_date_time_in_body

```python
def send_optional_unix_date_time_in_body(self,
                                        date_time=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | `datetime` | Form, Optional | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

date_time = dt.datetime.utcfromtimestamp(1484719381)

result = form_params_controller.send_optional_unix_date_time_in_body(date_time)
```

#### send_optional_rfc_1123_in_body

```python
def send_optional_rfc_1123_in_body(self,
                                  body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | `datetime` | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = APIHelper.HttpDateTime.from_value('Sun, 06 Nov 1994 08:49:37 GMT').datetime

result = form_params_controller.send_optional_rfc_1123_in_body(body)
```

#### send_datetime_optional_in_endpoint

```python
def send_datetime_optional_in_endpoint(self,
                                      body=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | `datetime` | Form, Optional | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python


result = form_params_controller.send_datetime_optional_in_endpoint()
```

#### send_optional_unix_time_stamp_in_model_body

```python
def send_optional_unix_time_stamp_in_model_body(self,
                                               date_time)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | [`UnixDateTime`](#unixdatetime) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

date_time = UnixDateTime()()
date_time.date_time = dt.datetime.utcfromtimestamp(1484719381)

result = form_params_controller.send_optional_unix_time_stamp_in_model_body(date_time)
```

#### send_optional_unix_time_stamp_in_nested_model_body

```python
def send_optional_unix_time_stamp_in_nested_model_body(self,
                                                      date_time)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | [`SendUnixDateTime`](#sendunixdatetime) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

date_time = SendUnixDateTime()()
date_time.date_time = UnixDateTime()()
date_time.date_time.date_time = dt.datetime.utcfromtimestamp(1484719381)

result = form_params_controller.send_optional_unix_time_stamp_in_nested_model_body(date_time)
```

#### send_rfc_1123_date_time_in_nested_model

```python
def send_rfc_1123_date_time_in_nested_model(self,
                                           body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`SendRfc1123DateTime`](#sendrfc1123datetime) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = SendRfc1123DateTime()()
body.date_time = ModelWithOptionalRfc1123DateTime()()
body.date_time.date_time = APIHelper.HttpDateTime.from_value('Sun, 06 Nov 1994 08:49:37 GMT').datetime

result = form_params_controller.send_rfc_1123_date_time_in_nested_model(body)
```

#### send_rfc_1123_date_time_in_model

```python
def send_rfc_1123_date_time_in_model(self,
                                    date_time)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | [`ModelWithOptionalRfc1123DateTime`](#modelwithoptionalrfc1123datetime) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

date_time = ModelWithOptionalRfc1123DateTime()()
date_time.date_time = APIHelper.HttpDateTime.from_value('Sun, 06 Nov 1994 08:49:37 GMT').datetime

result = form_params_controller.send_rfc_1123_date_time_in_model(date_time)
```

#### send_optional_datetime_in_model

```python
def send_optional_datetime_in_model(self,
                                   body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`ModelWithOptionalRfc3339DateTime`](#modelwithoptionalrfc3339datetime) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = ModelWithOptionalRfc3339DateTime()()
body.date_time = dateutil.parser.parse('1994-02-13T14:01:54.9571247Z')

result = form_params_controller.send_optional_datetime_in_model(body)
```

#### send_rfc_339_date_time_in_nested_models

```python
def send_rfc_339_date_time_in_nested_models(self,
                                           body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`SendRfc339DateTime`](#sendrfc339datetime) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = SendRfc339DateTime()()
body.date_time = ModelWithOptionalRfc3339DateTime()()
body.date_time.date_time = dateutil.parser.parse('1994-02-13T14:01:54.9571247Z')

result = form_params_controller.send_rfc_339_date_time_in_nested_models(body)
```

#### uuid_as_optional

```python
def uuid_as_optional(self,
                    body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`UuidAsOptional`](#uuidasoptional) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = UuidAsOptional()()
body.uuid = '123e4567-e89b-12d3-a456-426655440000'

result = form_params_controller.uuid_as_optional(body)
```

#### boolean_as_optional

```python
def boolean_as_optional(self,
                       body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`BooleanAsOptional`](#booleanasoptional) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = BooleanAsOptional()()
body.boolean = True

result = form_params_controller.boolean_as_optional(body)
```

#### date_as_optional

```python
def date_as_optional(self,
                    body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`DateAsOptional`](#dateasoptional) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = DateAsOptional()()
body.date = dateutil.parser.parse('1994-02-13').date()

result = form_params_controller.date_as_optional(body)
```

#### dynamic_as_optional

```python
def dynamic_as_optional(self,
                       body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`DynamicAsOptional`](#dynamicasoptional) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = DynamicAsOptional()()
body.dynamic = jsonpickle.decode('{"dynamic":"test"}')

result = form_params_controller.dynamic_as_optional(body)
```

#### string_as_optional

```python
def string_as_optional(self,
                      body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`StringAsOptional`](#stringasoptional) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = StringAsOptional()()
body.string = 'test'

result = form_params_controller.string_as_optional(body)
```

#### precision_as_optional

```python
def precision_as_optional(self,
                         body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`PrecisionAsOptional`](#precisionasoptional) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = PrecisionAsOptional()()
body.precision = 1.23

result = form_params_controller.precision_as_optional(body)
```

#### long_as_optional

```python
def long_as_optional(self,
                    body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`LongAsOptional`](#longasoptional) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = LongAsOptional()()
body.long = 123123

result = form_params_controller.long_as_optional(body)
```

#### send_number_as_optional

```python
def send_number_as_optional(self,
                           body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`NumberAsOptional`](#numberasoptional) | Form, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = NumberAsOptional()()
body.number = 1

result = form_params_controller.send_number_as_optional(body)
```

### `BodyParamsController`

#### Overview

##### Get instance

An instance of the `BodyParamsController` class can be accessed from the API Client.

```
body_params_controller = client.body_params
```

#### send_delete_plain_text

```python
def send_delete_plain_text(self,
                          text_string)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `text_string` | `string` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

text_string = 'textString2'

result = body_params_controller.send_delete_plain_text(text_string)
```

#### send_delete_body

```python
def send_delete_body(self,
                    body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`DeleteBody`](#deletebody) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = DeleteBody()()
body.name = 'name6'
body.field = 'field0'

result = body_params_controller.send_delete_body(body)
```

#### send_date_array

```python
def send_date_array(self,
                   dates)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `dates` | `List of date` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

dates = [dateutil.parser.parse('2016-03-13').date(), dateutil.parser.parse('2016-03-13').date()]

result = body_params_controller.send_date_array(dates)
```

#### send_date

```python
def send_date(self,
             date)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date` | `date` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

date = dateutil.parser.parse('2016-03-13').date()

result = body_params_controller.send_date(date)
```

#### send_unix_date_time

```python
def send_unix_date_time(self,
                       datetime)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetime` | `datetime` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetime = dt.datetime.utcfromtimestamp(1480809600)

result = body_params_controller.send_unix_date_time(datetime)
```

#### send_rfc_1123_date_time

```python
def send_rfc_1123_date_time(self,
                           datetime)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetime` | `datetime` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetime = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime

result = body_params_controller.send_rfc_1123_date_time(datetime)
```

#### send_rfc_3339_date_time

```python
def send_rfc_3339_date_time(self,
                           datetime)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetime` | `datetime` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')

result = body_params_controller.send_rfc_3339_date_time(datetime)
```

#### send_unix_date_time_array

```python
def send_unix_date_time_array(self,
                             datetimes)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetimes` | `List of datetime` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetimes = [dt.datetime.utcfromtimestamp(1480809600), dt.datetime.utcfromtimestamp(1480809600), dt.datetime.utcfromtimestamp(1480809600)]

result = body_params_controller.send_unix_date_time_array(datetimes)
```

#### send_rfc_1123_date_time_array

```python
def send_rfc_1123_date_time_array(self,
                                 datetimes)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetimes` | `List of datetime` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetimes = [APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime, APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime, APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime]

result = body_params_controller.send_rfc_1123_date_time_array(datetimes)
```

#### send_rfc_3339_date_time_array

```python
def send_rfc_3339_date_time_array(self,
                                 datetimes)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetimes` | `List of datetime` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetimes = [dateutil.parser.parse('2016-03-13T12:52:32.123Z'), dateutil.parser.parse('2016-03-13T12:52:32.123Z'), dateutil.parser.parse('2016-03-13T12:52:32.123Z')]

result = body_params_controller.send_rfc_3339_date_time_array(datetimes)
```

#### send_string_array

sends a string body param

```python
def send_string_array(self,
                     sarray)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `sarray` | `List of string` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

sarray = ['sarray8', 'sarray9']

result = body_params_controller.send_string_array(sarray)
```

#### update_string

```python
def update_string(self,
                 value)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `string` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

value = 'value2'

result = body_params_controller.update_string(value)
```

#### send_integer_array

```python
def send_integer_array(self,
                      integers)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `integers` | `List of int` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

integers = [45, 46, 47]

result = body_params_controller.send_integer_array(integers)
```

#### wrap_body_in_object

```python
def wrap_body_in_object(self,
                       field,
                       name)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `field` | `string` | Body, Required | - |
| `name` | `string` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

field = 'field6'
name = 'name0'

result = body_params_controller.wrap_body_in_object(field, name)
```

#### additional_model_parameters

```python
def additional_model_parameters(self,
                               model)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `model` | [`AdditionalModelParameters`](#additionalmodelparameters) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

model = AdditionalModelParameters()()
model.name = 'name2'
model.field = 'field4'
model.address = 'address8'
model.job = Job()()
model.job.company = 'company8'

result = body_params_controller.additional_model_parameters(model)
```

#### validate_required_parameter

```python
def validate_required_parameter(self,
                               model,
                               option=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `model` | [`Validate`](#validate) | Body, Required | - |
| `option` | `string` | Query, Optional | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

model = Validate()()
model.field = 'field4'
model.name = 'name2'

result = body_params_controller.validate_required_parameter(model)
```

#### additional_model_parameters_1

```python
def additional_model_parameters_1(self,
                                 model)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `model` | [`AdditionalModelParameters`](#additionalmodelparameters) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

model = AdditionalModelParameters()()
model.name = 'name2'
model.field = 'field4'
model.address = 'address8'
model.job = Job()()
model.job.company = 'company8'

result = body_params_controller.additional_model_parameters_1(model)
```

#### send_model

```python
def send_model(self,
              model)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `model` | [`Employee`](#employee) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

model = Employee()()
model.department = 'department8'
model.dependents = []

model.dependents.append(Person())
model.dependents[0].address = 'address5'
model.dependents[0].age = 237
model.dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
model.dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
model.dependents[0].name = 'name9'
model.dependents[0].uid = 'uid9'

model.hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
model.joining_day = Days.TUESDAY
model.salary = 240
model.working_days = [Days.THURSDAY, Days.WEDNESDAY_, Days.TUESDAY]
model.address = 'address8'
model.age = 186
model.birthday = dateutil.parser.parse('2016-03-13').date()
model.birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
model.name = 'name2'
model.uid = 'uid2'

result = body_params_controller.send_model(model)
```

#### send_model_array

```python
def send_model_array(self,
                    models)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `models` | [`List of Employee`](#employee) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

models = []

models.append(Employee())
models[0].department = 'department6'
models[0].dependents = []

models[0].dependents.append(Person())
models[0].dependents[0].address = 'address9'
models[0].dependents[0].age = 49
models[0].dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[0].name = 'name3'
models[0].dependents[0].uid = 'uid3'

models[0].dependents.append(Person())
models[0].dependents[1].address = 'address0'
models[0].dependents[1].age = 50
models[0].dependents[1].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[1].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[1].name = 'name4'
models[0].dependents[1].uid = 'uid4'

models[0].dependents.append(Person())
models[0].dependents[2].address = 'address1'
models[0].dependents[2].age = 51
models[0].dependents[2].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[2].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[2].name = 'name5'
models[0].dependents[2].uid = 'uid5'

models[0].hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
models[0].joining_day = Days.WEDNESDAY_
models[0].salary = 84
models[0].working_days = [Days.SUNDAY]
models[0].address = 'address2'
models[0].age = 254
models[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].name = 'name6'
models[0].uid = 'uid6'

models.append(Employee())
models[1].department = 'department7'
models[1].dependents = []

models[1].dependents.append(Person())
models[1].dependents[0].address = 'address0'
models[1].dependents[0].age = 50
models[1].dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[1].dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[1].dependents[0].name = 'name4'
models[1].dependents[0].uid = 'uid4'

models[1].hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
models[1].joining_day = Days.THURSDAY
models[1].salary = 85
models[1].working_days = [Days.MONDAY, Days.TUESDAY]
models[1].address = 'address3'
models[1].age = 255
models[1].birthday = dateutil.parser.parse('2016-03-13').date()
models[1].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[1].name = 'name7'
models[1].uid = 'uid7'


result = body_params_controller.send_model_array(models)
```

#### send_dynamic

```python
def send_dynamic(self,
                dynamic)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `dynamic` | `object` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

dynamic = jsonpickle.decode('{"key1":"val1","key2":"val2"}')

result = body_params_controller.send_dynamic(dynamic)
```

#### send_string

```python
def send_string(self,
               value)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `string` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

value = 'value2'

result = body_params_controller.send_string(value)
```

#### send_string_enum_array

```python
def send_string_enum_array(self,
                          days)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `days` | [`List of Days`](#days) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

days = [Days.SUNDAY, Days.MONDAY, Days.TUESDAY]

result = body_params_controller.send_string_enum_array(days)
```

#### send_integer_enum_array

```python
def send_integer_enum_array(self,
                           suites)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `suites` | [`List of SuiteCode`](#suitecode) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

suites = [SuiteCode.HEARTS, SuiteCode.SPADES, SuiteCode.CLUBS]

result = body_params_controller.send_integer_enum_array(suites)
```

#### update_model

```python
def update_model(self,
                model)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `model` | [`Employee`](#employee) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

model = Employee()()
model.department = 'department8'
model.dependents = []

model.dependents.append(Person())
model.dependents[0].address = 'address5'
model.dependents[0].age = 237
model.dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
model.dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
model.dependents[0].name = 'name9'
model.dependents[0].uid = 'uid9'

model.hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
model.joining_day = Days.TUESDAY
model.salary = 240
model.working_days = [Days.THURSDAY, Days.WEDNESDAY_, Days.TUESDAY]
model.address = 'address8'
model.age = 186
model.birthday = dateutil.parser.parse('2016-03-13').date()
model.birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
model.name = 'name2'
model.uid = 'uid2'

result = body_params_controller.update_model(model)
```

#### send_delete_body_with_model

```python
def send_delete_body_with_model(self,
                               model)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `model` | [`Employee`](#employee) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

model = Employee()()
model.department = 'department8'
model.dependents = []

model.dependents.append(Person())
model.dependents[0].address = 'address5'
model.dependents[0].age = 237
model.dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
model.dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
model.dependents[0].name = 'name9'
model.dependents[0].uid = 'uid9'

model.hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
model.joining_day = Days.TUESDAY
model.salary = 240
model.working_days = [Days.THURSDAY, Days.WEDNESDAY_, Days.TUESDAY]
model.address = 'address8'
model.age = 186
model.birthday = dateutil.parser.parse('2016-03-13').date()
model.birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
model.name = 'name2'
model.uid = 'uid2'

result = body_params_controller.send_delete_body_with_model(model)
```

#### send_delete_body_with_model_array

```python
def send_delete_body_with_model_array(self,
                                     models)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `models` | [`List of Employee`](#employee) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

models = []

models.append(Employee())
models[0].department = 'department6'
models[0].dependents = []

models[0].dependents.append(Person())
models[0].dependents[0].address = 'address9'
models[0].dependents[0].age = 49
models[0].dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[0].name = 'name3'
models[0].dependents[0].uid = 'uid3'

models[0].dependents.append(Person())
models[0].dependents[1].address = 'address0'
models[0].dependents[1].age = 50
models[0].dependents[1].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[1].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[1].name = 'name4'
models[0].dependents[1].uid = 'uid4'

models[0].dependents.append(Person())
models[0].dependents[2].address = 'address1'
models[0].dependents[2].age = 51
models[0].dependents[2].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[2].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[2].name = 'name5'
models[0].dependents[2].uid = 'uid5'

models[0].hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
models[0].joining_day = Days.WEDNESDAY_
models[0].salary = 84
models[0].working_days = [Days.SUNDAY]
models[0].address = 'address2'
models[0].age = 254
models[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].name = 'name6'
models[0].uid = 'uid6'

models.append(Employee())
models[1].department = 'department7'
models[1].dependents = []

models[1].dependents.append(Person())
models[1].dependents[0].address = 'address0'
models[1].dependents[0].age = 50
models[1].dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[1].dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[1].dependents[0].name = 'name4'
models[1].dependents[0].uid = 'uid4'

models[1].hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
models[1].joining_day = Days.THURSDAY
models[1].salary = 85
models[1].working_days = [Days.MONDAY, Days.TUESDAY]
models[1].address = 'address3'
models[1].age = 255
models[1].birthday = dateutil.parser.parse('2016-03-13').date()
models[1].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[1].name = 'name7'
models[1].uid = 'uid7'


result = body_params_controller.send_delete_body_with_model_array(models)
```

#### update_model_array

```python
def update_model_array(self,
                      models)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `models` | [`List of Employee`](#employee) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

models = []

models.append(Employee())
models[0].department = 'department6'
models[0].dependents = []

models[0].dependents.append(Person())
models[0].dependents[0].address = 'address9'
models[0].dependents[0].age = 49
models[0].dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[0].name = 'name3'
models[0].dependents[0].uid = 'uid3'

models[0].dependents.append(Person())
models[0].dependents[1].address = 'address0'
models[0].dependents[1].age = 50
models[0].dependents[1].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[1].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[1].name = 'name4'
models[0].dependents[1].uid = 'uid4'

models[0].dependents.append(Person())
models[0].dependents[2].address = 'address1'
models[0].dependents[2].age = 51
models[0].dependents[2].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].dependents[2].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].dependents[2].name = 'name5'
models[0].dependents[2].uid = 'uid5'

models[0].hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
models[0].joining_day = Days.WEDNESDAY_
models[0].salary = 84
models[0].working_days = [Days.SUNDAY]
models[0].address = 'address2'
models[0].age = 254
models[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[0].name = 'name6'
models[0].uid = 'uid6'

models.append(Employee())
models[1].department = 'department7'
models[1].dependents = []

models[1].dependents.append(Person())
models[1].dependents[0].address = 'address0'
models[1].dependents[0].age = 50
models[1].dependents[0].birthday = dateutil.parser.parse('2016-03-13').date()
models[1].dependents[0].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[1].dependents[0].name = 'name4'
models[1].dependents[0].uid = 'uid4'

models[1].hired_at = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime
models[1].joining_day = Days.THURSDAY
models[1].salary = 85
models[1].working_days = [Days.MONDAY, Days.TUESDAY]
models[1].address = 'address3'
models[1].age = 255
models[1].birthday = dateutil.parser.parse('2016-03-13').date()
models[1].birthtime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')
models[1].name = 'name7'
models[1].uid = 'uid7'


result = body_params_controller.update_model_array(models)
```

#### update_string_1

```python
def update_string_1(self,
                   value)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `string` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

value = 'value2'

result = body_params_controller.update_string_1(value)
```

#### update_string_array

```python
def update_string_array(self,
                       strings)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `strings` | `List of string` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

strings = ['strings5']

result = body_params_controller.update_string_array(strings)
```

#### send_string_with_new_line

```python
def send_string_with_new_line(self,
                             body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`TestNstringEncoding`](#testnstringencoding) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = TestNstringEncoding()()
body.field = 'field0'
body.name = 'name6'

result = body_params_controller.send_string_with_new_line(body)
```

#### send_string_with_r

```python
def send_string_with_r(self,
                      body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`TestRstringEncoding`](#testrstringencoding) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = TestRstringEncoding()()
body.field = 'field0'
body.name = 'name6'

result = body_params_controller.send_string_with_r(body)
```

#### send_string_in_body_with_r_n

```python
def send_string_in_body_with_r_n(self,
                                body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`TestRNstringEncoding`](#testrnstringencoding) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = TestRNstringEncoding()()
body.field = 'field0'
body.name = 'name6'

result = body_params_controller.send_string_in_body_with_r_n(body)
```

#### send_optional_unix_date_time_in_body

```python
def send_optional_unix_date_time_in_body(self,
                                        date_time=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | `datetime` | Body, Optional | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

date_time = dt.datetime.utcfromtimestamp(1484719381)

result = body_params_controller.send_optional_unix_date_time_in_body(date_time)
```

#### send_optional_rfc_1123_in_body

```python
def send_optional_rfc_1123_in_body(self,
                                  body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | `datetime` | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = APIHelper.HttpDateTime.from_value('Sun, 06 Nov 1994 08:49:37 GMT').datetime

result = body_params_controller.send_optional_rfc_1123_in_body(body)
```

#### send_datetime_optional_in_endpoint

```python
def send_datetime_optional_in_endpoint(self,
                                      body=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | `datetime` | Body, Optional | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python


result = body_params_controller.send_datetime_optional_in_endpoint()
```

#### send_optional_unix_time_stamp_in_model_body

```python
def send_optional_unix_time_stamp_in_model_body(self,
                                               date_time)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | [`UnixDateTime`](#unixdatetime) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

date_time = UnixDateTime()()
date_time.date_time = dt.datetime.utcfromtimestamp(1484719381)

result = body_params_controller.send_optional_unix_time_stamp_in_model_body(date_time)
```

#### send_optional_unix_time_stamp_in_nested_model_body

```python
def send_optional_unix_time_stamp_in_nested_model_body(self,
                                                      date_time)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | [`SendUnixDateTime`](#sendunixdatetime) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

date_time = SendUnixDateTime()()
date_time.date_time = UnixDateTime()()
date_time.date_time.date_time = dt.datetime.utcfromtimestamp(1484719381)

result = body_params_controller.send_optional_unix_time_stamp_in_nested_model_body(date_time)
```

#### send_rfc_1123_date_time_in_nested_model

```python
def send_rfc_1123_date_time_in_nested_model(self,
                                           body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`SendRfc1123DateTime`](#sendrfc1123datetime) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = SendRfc1123DateTime()()
body.date_time = ModelWithOptionalRfc1123DateTime()()
body.date_time.date_time = APIHelper.HttpDateTime.from_value('Sun, 06 Nov 1994 08:49:37 GMT').datetime

result = body_params_controller.send_rfc_1123_date_time_in_nested_model(body)
```

#### send_rfc_1123_date_time_in_model

```python
def send_rfc_1123_date_time_in_model(self,
                                    date_time)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | [`ModelWithOptionalRfc1123DateTime`](#modelwithoptionalrfc1123datetime) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

date_time = ModelWithOptionalRfc1123DateTime()()
date_time.date_time = APIHelper.HttpDateTime.from_value('Sun, 06 Nov 1994 08:49:37 GMT').datetime

result = body_params_controller.send_rfc_1123_date_time_in_model(date_time)
```

#### send_optional_datetime_in_model

```python
def send_optional_datetime_in_model(self,
                                   body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`ModelWithOptionalRfc3339DateTime`](#modelwithoptionalrfc3339datetime) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = ModelWithOptionalRfc3339DateTime()()
body.date_time = dateutil.parser.parse('1994-02-13T14:01:54.9571247Z')

result = body_params_controller.send_optional_datetime_in_model(body)
```

#### send_rfc_339_date_time_in_nested_models

```python
def send_rfc_339_date_time_in_nested_models(self,
                                           body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`SendRfc339DateTime`](#sendrfc339datetime) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = SendRfc339DateTime()()
body.date_time = ModelWithOptionalRfc3339DateTime()()
body.date_time.date_time = dateutil.parser.parse('1994-02-13T14:01:54.9571247Z')

result = body_params_controller.send_rfc_339_date_time_in_nested_models(body)
```

#### uuid_as_optional

```python
def uuid_as_optional(self,
                    body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`UuidAsOptional`](#uuidasoptional) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = UuidAsOptional()()
body.uuid = '123e4567-e89b-12d3-a456-426655440000'

result = body_params_controller.uuid_as_optional(body)
```

#### boolean_as_optional

```python
def boolean_as_optional(self,
                       body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`BooleanAsOptional`](#booleanasoptional) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = BooleanAsOptional()()
body.boolean = True

result = body_params_controller.boolean_as_optional(body)
```

#### date_as_optional

```python
def date_as_optional(self,
                    body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`DateAsOptional`](#dateasoptional) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = DateAsOptional()()
body.date = dateutil.parser.parse('1994-02-13').date()

result = body_params_controller.date_as_optional(body)
```

#### dynamic_as_optional

```python
def dynamic_as_optional(self,
                       body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`DynamicAsOptional`](#dynamicasoptional) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = DynamicAsOptional()()
body.dynamic = jsonpickle.decode('{"dynamic":"test"}')

result = body_params_controller.dynamic_as_optional(body)
```

#### string_as_optional

```python
def string_as_optional(self,
                      body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`StringAsOptional`](#stringasoptional) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = StringAsOptional()()
body.string = 'test'

result = body_params_controller.string_as_optional(body)
```

#### precision_as_optional

```python
def precision_as_optional(self,
                         body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`PrecisionAsOptional`](#precisionasoptional) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = PrecisionAsOptional()()
body.precision = 1.23

result = body_params_controller.precision_as_optional(body)
```

#### long_as_optional

```python
def long_as_optional(self,
                    body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`LongAsOptional`](#longasoptional) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = LongAsOptional()()
body.long = 123123

result = body_params_controller.long_as_optional(body)
```

#### send_number_as_optional

```python
def send_number_as_optional(self,
                           body)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | [`NumberAsOptional`](#numberasoptional) | Body, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

body = NumberAsOptional()()
body.number = 1

result = body_params_controller.send_number_as_optional(body)
```

### `ErrorCodesController`

#### Overview

##### Get instance

An instance of the `ErrorCodesController` class can be accessed from the API Client.

```
error_codes_controller = client.error_codes
```

#### catch_412_global_error

```python
def catch_412_global_error(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.catch_412_global_error()
```

#### get_501

```python
def get_501(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.get_501()
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 501 | error 501 | [`NestedModelException`](#nestedmodelexception) |

#### get_400

```python
def get_400(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.get_400()
```

#### get_500

```python
def get_500(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.get_500()
```

#### get_401

```python
def get_401(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.get_401()
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 401 | 401 Local | [`LocalTestException`](#localtestexception) |
| 421 | Default | [`LocalTestException`](#localtestexception) |
| 431 | Default | [`LocalTestException`](#localtestexception) |
| 432 | Default | [`LocalTestException`](#localtestexception) |
| 441 | Default | [`LocalTestException`](#localtestexception) |
| Default | Invalid response. | [`LocalTestException`](#localtestexception) |

#### receive_exception_with_unixtimestamp_exception

```python
def receive_exception_with_unixtimestamp_exception(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.receive_exception_with_unixtimestamp_exception()
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 444 | unixtimestamp exception | [`UnixTimeStampException`](#unixtimestampexception) |

#### receive_exception_with_rfc_1123_datetime

```python
def receive_exception_with_rfc_1123_datetime(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.receive_exception_with_rfc_1123_datetime()
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 444 | Rfc1123 Exception | [`Rfc1123Exception`](#rfc1123exception) |

#### receive_exception_with_rfc_3339_datetime

```python
def receive_exception_with_rfc_3339_datetime(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.receive_exception_with_rfc_3339_datetime()
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 444 | DateTime Exception | [`ExceptionWithRfc3339DateTimeException`](#exceptionwithrfc3339datetimeexception) |

#### receive_endpoint_level_exception

```python
def receive_endpoint_level_exception(self)
```

##### Response Type

[`Complex5`](#complex5)

##### Example Usage

```python

result = error_codes_controller.receive_endpoint_level_exception()
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 451 | caught endpoint exception | [`CustomErrorResponseException`](#customerrorresponseexception) |

#### receive_global_level_exception

```python
def receive_global_level_exception(self)
```

##### Response Type

[`Complex5`](#complex5)

##### Example Usage

```python

result = error_codes_controller.receive_global_level_exception()
```

#### date_in_exception

```python
def date_in_exception(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.date_in_exception()
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 444 | date in exception | [`ExceptionWithDateException`](#exceptionwithdateexception) |

#### uuid_in_exception

```python
def uuid_in_exception(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.uuid_in_exception()
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 444 | uuid in exception | [`ExceptionWithUUIDException`](#exceptionwithuuidexception) |

#### dynamic_in_exception

```python
def dynamic_in_exception(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.dynamic_in_exception()
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 444 | dynamic in Exception | [`ExceptionWithDynamicException`](#exceptionwithdynamicexception) |

#### precision_in_exception

```python
def precision_in_exception(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.precision_in_exception()
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 444 | precision in Exception | [`ExceptionWithPrecisionException`](#exceptionwithprecisionexception) |

#### boolean_in_exception

```python
def boolean_in_exception(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.boolean_in_exception()
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 444 | Boolean in Exception | [`ExceptionWithBooleanException`](#exceptionwithbooleanexception) |

#### long_in_exception

```python
def long_in_exception(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.long_in_exception()
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 444 | long in exception | [`ExceptionWithLongException`](#exceptionwithlongexception) |

#### number_in_exception

```python
def number_in_exception(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.number_in_exception()
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 444 | number in exception | [`ExceptionWithNumberException`](#exceptionwithnumberexception) |

#### get_exception_with_string

```python
def get_exception_with_string(self)
```

##### Response Type

`mixed`

##### Example Usage

```python

result = error_codes_controller.get_exception_with_string()
```

##### Errors

| HTTP Status Code | Error Description | Exception Class |
|  --- | --- | --- |
| 444 | exception with string | [`ExceptionWithStringException`](#exceptionwithstringexception) |

### `QueryParamController`

#### Overview

##### Get instance

An instance of the `QueryParamController` class can be accessed from the API Client.

```
query_param_controller = client.query_param
```

#### date_array

```python
def date_array(self,
              dates)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `dates` | `List of date` | Query, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

dates = [dateutil.parser.parse('2016-03-13').date(), dateutil.parser.parse('2016-03-13').date()]

result = query_param_controller.date_array(dates)
```

#### optional_dynamic_query_param

get optional dynamic query parameter

```python
def optional_dynamic_query_param(self,
                                name,
                                _optional_query_parameters=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `name` | `string` | Query, Required | - |
| `_optional_query_parameters` | `array` | Optional | Pass additional query parameters. |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

name = 'name0'
_optional_query_parameters = {'key0' : 'additionalQueryParams2' } 

result = query_param_controller.optional_dynamic_query_param(name, _optional_query_parameters)
```

#### date

```python
def date(self,
        date)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date` | `date` | Query, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

date = dateutil.parser.parse('2016-03-13').date()

result = query_param_controller.date(date)
```

#### unix_date_time_array

```python
def unix_date_time_array(self,
                        datetimes)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetimes` | `List of datetime` | Query, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetimes = [dt.datetime.utcfromtimestamp(1480809600), dt.datetime.utcfromtimestamp(1480809600), dt.datetime.utcfromtimestamp(1480809600)]

result = query_param_controller.unix_date_time_array(datetimes)
```

#### unix_date_time

```python
def unix_date_time(self,
                  datetime)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetime` | `datetime` | Query, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetime = dt.datetime.utcfromtimestamp(1480809600)

result = query_param_controller.unix_date_time(datetime)
```

#### rfc_1123_date_time

```python
def rfc_1123_date_time(self,
                      datetime)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetime` | `datetime` | Query, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetime = APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime

result = query_param_controller.rfc_1123_date_time(datetime)
```

#### rfc_1123_date_time_array

```python
def rfc_1123_date_time_array(self,
                            datetimes)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetimes` | `List of datetime` | Query, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetimes = [APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime, APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime, APIHelper.HttpDateTime.from_value('Mon, 15 Jun 2009 20:45:30 GMT').datetime]

result = query_param_controller.rfc_1123_date_time_array(datetimes)
```

#### rfc_3339_date_time_array

```python
def rfc_3339_date_time_array(self,
                            datetimes)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetimes` | `List of datetime` | Query, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetimes = [dateutil.parser.parse('2016-03-13T12:52:32.123Z'), dateutil.parser.parse('2016-03-13T12:52:32.123Z'), dateutil.parser.parse('2016-03-13T12:52:32.123Z')]

result = query_param_controller.rfc_3339_date_time_array(datetimes)
```

#### rfc_3339_date_time

```python
def rfc_3339_date_time(self,
                      datetime)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `datetime` | `datetime` | Query, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

datetime = dateutil.parser.parse('2016-03-13T12:52:32.123Z')

result = query_param_controller.rfc_3339_date_time(datetime)
```

#### no_params

```python
def no_params(self)
```

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

result = query_param_controller.no_params()
```

#### string_param

```python
def string_param(self,
                string)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `string` | `string` | Query, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

string = 'string4'

result = query_param_controller.string_param(string)
```

#### url_param

```python
def url_param(self,
             url)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `url` | `string` | Query, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

url = 'url4'

result = query_param_controller.url_param(url)
```

#### number_array

```python
def number_array(self,
                integers)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `integers` | `List of int` | Query, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

integers = [45, 46, 47]

result = query_param_controller.number_array(integers)
```

#### string_array

```python
def string_array(self,
                strings)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `strings` | `List of string` | Query, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

strings = ['strings5']

result = query_param_controller.string_array(strings)
```

#### simple_query

```python
def simple_query(self,
                boolean,
                number,
                string,
                _optional_query_parameters=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `boolean` | `bool` | Query, Required | - |
| `number` | `int` | Query, Required | - |
| `string` | `string` | Query, Required | - |
| `_optional_query_parameters` | `array` | Optional | Pass additional query parameters. |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

boolean = False
number = 158
string = 'string4'
_optional_query_parameters = {'key0' : 'additionalQueryParams2' } 

result = query_param_controller.simple_query(boolean, number, string, _optional_query_parameters)
```

#### string_enum_array

```python
def string_enum_array(self,
                     days)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `days` | [`List of Days`](#days) | Query, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

days = [Days.SUNDAY, Days.MONDAY, Days.TUESDAY]

result = query_param_controller.string_enum_array(days)
```

#### multiple_params

```python
def multiple_params(self,
                   number,
                   precision,
                   string,
                   url)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `number` | `int` | Query, Required | - |
| `precision` | `float` | Query, Required | - |
| `string` | `string` | Query, Required | - |
| `url` | `string` | Query, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

number = 158
precision = 112.04
string = 'string4'
url = 'url4'

result = query_param_controller.multiple_params(number, precision, string, url)
```

#### integer_enum_array

```python
def integer_enum_array(self,
                      suites)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `suites` | [`List of SuiteCode`](#suitecode) | Query, Required | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

suites = [SuiteCode.HEARTS, SuiteCode.SPADES, SuiteCode.CLUBS]

result = query_param_controller.integer_enum_array(suites)
```

### `EchoController`

#### Overview

##### Get instance

An instance of the `EchoController` class can be accessed from the API Client.

```
echo_controller = client.echo
```

#### json_echo

Echo's back the request

```python
def json_echo(self,
             input)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `input` | `object` | Body, Required | - |

##### Response Type

`mixed`

##### Example Usage

```python

input = jsonpickle.decode('{"key1":"val1","key2":"val2"}')

result = echo_controller.json_echo(input)
```

#### form_echo

Sends the request including any form params as JSON

```python
def form_echo(self,
             input)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `input` | `object` | Form, Required | - |

##### Response Type

`mixed`

##### Example Usage

```python

input = jsonpickle.decode('{"key1":"val1","key2":"val2"}')

result = echo_controller.form_echo(input)
```

#### query_echo

```python
def query_echo(self,
              _optional_query_parameters=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `_optional_query_parameters` | `array` | Optional | Pass additional query parameters. |

##### Response Type

[`EchoResponse`](#echoresponse)

##### Example Usage

```python

_optional_query_parameters = {'key0' : 'additionalQueryParams2' } 

result = echo_controller.query_echo(_optional_query_parameters)
```

### `HeaderController`

#### Overview

##### Get instance

An instance of the `HeaderController` class can be accessed from the API Client.

```
header_controller = client.header
```

#### send_headers

Sends a single header params

```python
def send_headers(self,
                custom_header,
                value)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `custom_header` | `string` | Header, Required | - |
| `value` | `string` | Form, Required | Represents the value of the custom header |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

custom_header = 'custom-header2'
value = 'value2'

result = header_controller.send_headers(custom_header, value)
```

### `TemplateParamsController`

#### Overview

##### Get instance

An instance of the `TemplateParamsController` class can be accessed from the API Client.

```
template_params_controller = client.template_params
```

#### send_string_array

```python
def send_string_array(self,
                     strings)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `strings` | `List of string` | Template, Required | - |

##### Response Type

[`EchoResponse`](#echoresponse)

##### Example Usage

```python

strings = ['strings5']

result = template_params_controller.send_string_array(strings)
```

#### send_integer_array

```python
def send_integer_array(self,
                      integers)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `integers` | `List of int` | Template, Required | - |

##### Response Type

[`EchoResponse`](#echoresponse)

##### Example Usage

```python

integers = [45, 46, 47]

result = template_params_controller.send_integer_array(integers)
```

### `QueryParamsController`

#### Overview

##### Get instance

An instance of the `QueryParamsController` class can be accessed from the API Client.

```
query_params_controller = client.query_params
```

#### send_number_as_optional

```python
def send_number_as_optional(self,
                           number,
                           number_1=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `number` | `int` | Query, Required | - |
| `number_1` | `int` | Query, Optional | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

number = 1
number_1 = 1

result = query_params_controller.send_number_as_optional(number, number_1)
```

#### send_long_as_optional

```python
def send_long_as_optional(self,
                         long,
                         long_1=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `long` | `long|int` | Query, Required | - |
| `long_1` | `long|int` | Query, Optional | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

long = 123123
long_1 = 123123

result = query_params_controller.send_long_as_optional(long, long_1)
```

#### precision_as_optional

```python
def precision_as_optional(self,
                         precision,
                         precision_1=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `precision` | `float` | Query, Required | - |
| `precision_1` | `float` | Query, Optional | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

precision = 1.23
precision_1 = 1.23

result = query_params_controller.precision_as_optional(precision, precision_1)
```

#### boolean_as_optional

```python
def boolean_as_optional(self,
                       boolean,
                       boolean_1=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `boolean` | `bool` | Query, Required | - |
| `boolean_1` | `bool` | Query, Optional | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

boolean = True
boolean_1 = True

result = query_params_controller.boolean_as_optional(boolean, boolean_1)
```

#### rfc_1123_datetime_as_optional

```python
def rfc_1123_datetime_as_optional(self,
                                 date_time,
                                 date_time_1=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | `datetime` | Query, Required | - |
| `date_time_1` | `datetime` | Query, Optional | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

date_time = APIHelper.HttpDateTime.from_value('Sun, 06 Nov 1994 08:49:37 GMT').datetime
date_time_1 = APIHelper.HttpDateTime.from_value('Sun, 06 Nov 1994 08:49:37 GMT').datetime

result = query_params_controller.rfc_1123_datetime_as_optional(date_time, date_time_1)
```

#### rfc_3339_datetime_as_optional

```python
def rfc_3339_datetime_as_optional(self,
                                 date_time,
                                 date_time_1=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | `datetime` | Query, Required | - |
| `date_time_1` | `datetime` | Query, Optional | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

date_time = dateutil.parser.parse('1994-02-13 14:01:54')
date_time_1 = dateutil.parser.parse('1994-02-13 14:01:54')

result = query_params_controller.rfc_3339_datetime_as_optional(date_time, date_time_1)
```

#### send_date_as_optional

```python
def send_date_as_optional(self,
                         date,
                         date_1=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date` | `date` | Query, Required | - |
| `date_1` | `date` | Query, Optional | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

date = dateutil.parser.parse('1994-02-13').date()
date_1 = dateutil.parser.parse('1994-02-13').date()

result = query_params_controller.send_date_as_optional(date, date_1)
```

#### send_string_as_optional

```python
def send_string_as_optional(self,
                           string,
                           string_1=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `string` | `string` | Query, Required | - |
| `string_1` | `string` | Query, Optional | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

string = 'test'
string_1 = 'test'

result = query_params_controller.send_string_as_optional(string, string_1)
```

#### unixdatetime_as_optional

```python
def unixdatetime_as_optional(self,
                            date_time,
                            date_time_1=None)
```

##### Parameters

| Parameter | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | `datetime` | Query, Required | - |
| `date_time_1` | `datetime` | Query, Optional | - |

##### Response Type

[`ServerResponse`](#serverresponse)

##### Example Usage

```python

date_time = dt.datetime.utcfromtimestamp(1484719381)
date_time_1 = dt.datetime.utcfromtimestamp(1484719381)

result = query_params_controller.unixdatetime_as_optional(date_time, date_time_1)
```

## Model Reference

### Structures

* [Employee](#employee)
* [Boss](#boss)
* [DeleteBody](#deletebody)
* [EchoResponse](#echoresponse)
* [Person](#person)
* [ServerResponse](#serverresponse)
* [QueryParameter](#queryparameter)
* [Job](#job)
* [AdditionalModelParameters](#additionalmodelparameters)
* [Validate](#validate)
* [TestNstringEncoding](#testnstringencoding)
* [TestRstringEncoding](#testrstringencoding)
* [TestRNstringEncoding](#testrnstringencoding)
* [SendRfc1123DateTime](#sendrfc1123datetime)
* [ModelWithOptionalRfc1123DateTime](#modelwithoptionalrfc1123datetime)
* [SendRfc339DateTime](#sendrfc339datetime)
* [UuidAsOptional](#uuidasoptional)
* [DynamicAsOptional](#dynamicasoptional)
* [ModelWithOptionalRfc3339DateTime](#modelwithoptionalrfc3339datetime)
* [UnixDateTime](#unixdatetime)
* [SendUnixDateTime](#sendunixdatetime)
* [PrecisionAsOptional](#precisionasoptional)
* [StringAsOptional](#stringasoptional)
* [LongAsOptional](#longasoptional)
* [NumberAsOptional](#numberasoptional)
* [BooleanAsOptional](#booleanasoptional)
* [SoftwareTester](#softwaretester)
* [Developer](#developer)
* [GlossEntry](#glossentry)
* [Mineral](#mineral)
* [Diuretic](#diuretic)
* [BossCompany](#bosscompany)
* [BetaBlocker](#betablocker)
* [Anticoagulant](#anticoagulant)
* [EmployeeComp](#employeecomp)
* [Company](#company)
* [Attributes](#attributes)
* [ResponseWithEnum](#responsewithenum)
* [GlossDef](#glossdef)
* [GlossList](#glosslist)
* [GlossDiv](#glossdiv)
* [Glossary](#glossary)
* [Imaging](#imaging)
* [Lab](#lab)
* [Antianginal](#antianginal)
* [AceInhibitor](#aceinhibitor)
* [Medication](#medication)
* [Complex1](#complex1)
* [Complex2](#complex2)
* [Advanced](#advanced)
* [DataToSign](#datatosign)
* [ContactDetails](#contactdetails)
* [Styling](#styling)
* [Dialogs](#dialogs)
* [SignatureType](#signaturetype)
* [RedirectSettings](#redirectsettings)
* [TimeToLive](#timetolive)
* [Status](#status)
* [Before](#before)
* [Ui](#ui)
* [Complex3](#complex3)
* [Signer](#signer)
* [Complex5](#complex5)
* [ResponseData](#responsedata)
* [Feed](#feed)
* [Entry](#entry)
* [DateAsOptional](#dateasoptional)
* [AddPrecisionInException](#addprecisioninexception)
* [AddUuidInGlobalException](#adduuidinglobalexception)
* [AddRfc1123DatetimeInGlobalException](#addrfc1123datetimeinglobalexception)
* [AddNumberInException](#addnumberinexception)
* [AddDynamicInException](#adddynamicinexception)
* [AddRfc3339DatetimeInGlobalException](#addrfc3339datetimeinglobalexception)
* [AddBooleanInGlobalException](#addbooleaninglobalexception)
* [AddDateInGlobalException](#adddateinglobalexception)
* [AddStringInGlobalException](#addstringinglobalexception)
* [AddUnixTimeStampInGlobalException](#addunixtimestampinglobalexception)
* [AddLongInGlobalException](#addlonginglobalexception)

#### Employee

##### Class Name

`Employee`

##### Inherits From

[`Person`](#person)

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `department` | `string` |  | - |
| `dependents` | [`List of Person`](#person) |  | - |
| `hired_at` | `datetime` |  | - |
| `joining_day` | [`Days`](#days) |  | *Default: `'Monday'`* |
| `salary` | `int` |  | - |
| `working_days` | [`List of Days`](#days) |  | - |
| `boss` | [`Person`](#person) | Optional | - |

##### Example (as JSON)

```json
{
  "department": "department0",
  "dependents": [
    {
      "address": "address3",
      "age": 45,
      "birthday": "2016-03-13",
      "birthtime": "2016-03-13T12:52:32.123Z",
      "name": "name7",
      "uid": "uid7",
      "personType": null
    },
    {
      "address": "address4",
      "age": 46,
      "birthday": "2016-03-13",
      "birthtime": "2016-03-13T12:52:32.123Z",
      "name": "name8",
      "uid": "uid8",
      "personType": null
    },
    {
      "address": "address5",
      "age": 47,
      "birthday": "2016-03-13",
      "birthtime": "2016-03-13T12:52:32.123Z",
      "name": "name9",
      "uid": "uid9",
      "personType": null
    }
  ],
  "hiredAt": "Mon, 15 Jun 2009 20:45:30 GMT",
  "joiningDay": "Sunday",
  "salary": 176,
  "workingDays": [
    "Monday"
  ],
  "boss": null,
  "address": "address6",
  "age": 250,
  "birthday": "2016-03-13",
  "birthtime": "2016-03-13T12:52:32.123Z",
  "name": "name0",
  "uid": "uid0",
  "personType": null
}
```

#### Boss

Testing circular reference.

##### Class Name

`Boss`

##### Inherits From

[`Employee`](#employee)

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `promoted_at` | `datetime` |  | - |
| `assistant` | [`Employee`](#employee) | Optional | - |

##### Example (as JSON)

```json
{
  "promotedAt": 1480809600,
  "assistant": null,
  "department": "department0",
  "dependents": [
    {
      "address": "address3",
      "age": 45,
      "birthday": "2016-03-13",
      "birthtime": "2016-03-13T12:52:32.123Z",
      "name": "name7",
      "uid": "uid7",
      "personType": null
    },
    {
      "address": "address4",
      "age": 46,
      "birthday": "2016-03-13",
      "birthtime": "2016-03-13T12:52:32.123Z",
      "name": "name8",
      "uid": "uid8",
      "personType": null
    },
    {
      "address": "address5",
      "age": 47,
      "birthday": "2016-03-13",
      "birthtime": "2016-03-13T12:52:32.123Z",
      "name": "name9",
      "uid": "uid9",
      "personType": null
    }
  ],
  "hiredAt": "Mon, 15 Jun 2009 20:45:30 GMT",
  "joiningDay": "Sunday",
  "salary": 176,
  "workingDays": [
    "Monday"
  ],
  "boss": null,
  "address": "address6",
  "age": 250,
  "birthday": "2016-03-13",
  "birthtime": "2016-03-13T12:52:32.123Z",
  "name": "name0",
  "uid": "uid0",
  "personType": null
}
```

#### DeleteBody

##### Class Name

`DeleteBody`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `name` | `string` | - |
| `field` | `string` | - |

##### Example (as JSON)

```json
{
  "name": "name0",
  "field": "field6"
}
```

#### EchoResponse

Raw http Request info

##### Class Name

`EchoResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `body` | `dict` | Optional | - |
| `headers` | `dict` | Optional | - |
| `method` | `string` | Optional | - |
| `path` | `string` | Optional | relativePath |
| `query` | [`dict`](#queryparameter) | Optional | - |
| `upload_count` | `int` | Optional | - |

##### Example (as JSON)

```json
{
  "body": null,
  "headers": null,
  "method": null,
  "path": null,
  "query": null,
  "uploadCount": null
}
```

#### Person

##### Class Name

`Person`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `address` | `string` |  | - |
| `age` | `long|int` |  | - |
| `birthday` | `date` |  | - |
| `birthtime` | `datetime` |  | - |
| `name` | `string` |  | - |
| `uid` | `string` |  | - |
| `person_type` | `string` | Optional | - |

##### Example (as JSON)

```json
{
  "address": "address6",
  "age": 250,
  "birthday": "2016-03-13",
  "birthtime": "2016-03-13T12:52:32.123Z",
  "name": "name0",
  "uid": "uid0",
  "personType": null
}
```

#### ServerResponse

##### Class Name

`ServerResponse`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `passed` | `bool` |  | - |
| `message` | `string` | Optional | - |
| `input` | `dict` | Optional | - |

##### Example (as JSON)

```json
{
  "passed": false,
  "Message": null,
  "input": null
}
```

#### QueryParameter

Query parameter key value pair echoed back from the server.

##### Class Name

`QueryParameter`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `key` | `string` | Optional | - |

##### Example (as JSON)

```json
{
  "key": null
}
```

#### Job

##### Class Name

`Job`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `company` | `string` | - |

##### Example (as JSON)

```json
{
  "company": "company0"
}
```

#### AdditionalModelParameters

##### Class Name

`AdditionalModelParameters`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `name` | `string` | - |
| `field` | `string` | - |
| `address` | `string` | - |
| `job` | [`Job`](#job) | - |

##### Example (as JSON)

```json
{
  "name": "name0",
  "field": "field6",
  "address": "address6",
  "Job": {
    "company": "company6"
  }
}
```

#### Validate

##### Class Name

`Validate`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `field` | `string` |  | - |
| `name` | `string` |  | - |
| `address` | `string` | Optional | - |

##### Example (as JSON)

```json
{
  "field": "field6",
  "name": "name0",
  "address": null
}
```

#### TestNstringEncoding

##### Class Name

`TestNstringEncoding`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `field` | `string` | - |
| `name` | `string` | - |

##### Example (as JSON)

```json
{
  "field": "field6",
  "name": "name0"
}
```

#### TestRstringEncoding

##### Class Name

`TestRstringEncoding`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `field` | `string` | - |
| `name` | `string` | - |

##### Example (as JSON)

```json
{
  "field": "field6",
  "name": "name0"
}
```

#### TestRNstringEncoding

##### Class Name

`TestRNstringEncoding`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `field` | `string` | - |
| `name` | `string` | - |

##### Example (as JSON)

```json
{
  "field": "field6",
  "name": "name0"
}
```

#### SendRfc1123DateTime

##### Class Name

`SendRfc1123DateTime`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | [`ModelWithOptionalRfc1123DateTime`](#modelwithoptionalrfc1123datetime) | Optional | - |

##### Example (as JSON)

```json
{
  "dateTime": null
}
```

#### ModelWithOptionalRfc1123DateTime

##### Class Name

`ModelWithOptionalRfc1123DateTime`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | `datetime` | Optional | - |

##### Example (as JSON)

```json
{
  "dateTime": null
}
```

#### SendRfc339DateTime

##### Class Name

`SendRfc339DateTime`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | [`ModelWithOptionalRfc3339DateTime`](#modelwithoptionalrfc3339datetime) | Optional | - |

##### Example (as JSON)

```json
{
  "dateTime": {
    "dateTime": "1994-02-13T14:01:54.9571247Z"
  }
}
```

#### UuidAsOptional

##### Class Name

`UuidAsOptional`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `uuid` | `uuid|string` | Optional | - |

##### Example (as JSON)

```json
{
  "uuid": null
}
```

#### DynamicAsOptional

##### Class Name

`DynamicAsOptional`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `dynamic` | `object` | Optional | - |

##### Example (as JSON)

```json
{
  "dynamic": null
}
```

#### ModelWithOptionalRfc3339DateTime

##### Class Name

`ModelWithOptionalRfc3339DateTime`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | `datetime` | Optional | - |

##### Example (as JSON)

```json
{
  "dateTime": null
}
```

#### UnixDateTime

##### Class Name

`UnixDateTime`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | `datetime` | Optional | - |

##### Example (as JSON)

```json
{
  "dateTime": null
}
```

#### SendUnixDateTime

##### Class Name

`SendUnixDateTime`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | [`UnixDateTime`](#unixdatetime) | Optional | - |

##### Example (as JSON)

```json
{
  "dateTime": null
}
```

#### PrecisionAsOptional

##### Class Name

`PrecisionAsOptional`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `precision` | `float` | Optional | - |

##### Example (as JSON)

```json
{
  "precision": null
}
```

#### StringAsOptional

##### Class Name

`StringAsOptional`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `string` | `string` | Optional | - |

##### Example (as JSON)

```json
{
  "string": null
}
```

#### LongAsOptional

##### Class Name

`LongAsOptional`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `long` | `long|int` | Optional | - |

##### Example (as JSON)

```json
{
  "long": null
}
```

#### NumberAsOptional

##### Class Name

`NumberAsOptional`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `number` | `int` | Optional | - |

##### Example (as JSON)

```json
{
  "number": null
}
```

#### BooleanAsOptional

##### Class Name

`BooleanAsOptional`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `boolean` | `bool` | Optional | - |

##### Example (as JSON)

```json
{
  "boolean": null
}
```

#### SoftwareTester

##### Class Name

`SoftwareTester`

##### Inherits From

[`EmployeeComp`](#employeecomp)

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `team` | `string` | - |
| `designation` | `string` | - |
| `role` | `string` | - |

##### Example (as JSON)

```json
{
  "company name": "APIMatic",
  "address": "nust",
  "cell number": "090078601",
  "first name": "Muhammad",
  "last name": "Farhan",
  "id": "123456",
  "team": "Testing",
  "designation": "Tester",
  "role": "Testing"
}
```

#### Developer

##### Class Name

`Developer`

##### Inherits From

[`EmployeeComp`](#employeecomp)

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `team` | `string` | - |
| `designation` | `string` | - |
| `role` | `string` | - |

##### Example (as JSON)

```json
{
  "company name": "APIMatic",
  "address": "nust",
  "cell number": "090078601",
  "first name": "Muhammad",
  "last name": "Farhan",
  "id": "123456",
  "team": "CORE",
  "designation": "Manager",
  "role": "Team Lead"
}
```

#### GlossEntry

##### Class Name

`GlossEntry`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `id` | `string` | - |
| `sort_as` | `string` | - |
| `gloss_term` | `string` | - |
| `acronym` | `string` | - |
| `abbrev` | `string` | - |
| `gloss_def` | [`GlossDef`](#glossdef) | - |
| `gloss_see` | `string` | - |

##### Example (as JSON)

```json
{
  "ID": "SGML",
  "SortAs": "SGML",
  "GlossTerm": "Standard Generalized Markup Language",
  "Acronym": "SGML",
  "Abbrev": "ISO 8879:1986",
  "GlossDef": {
    "para": "A meta-markup language, used to create markup languages such as DocBook.",
    "GlossSeeAlso": [
      "GML",
      "XML"
    ]
  },
  "GlossSee": "markup"
}
```

#### Mineral

##### Class Name

`Mineral`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `name` | `string` | - |
| `strength` | `string` | - |
| `dose` | `string` | - |
| `route` | `string` | - |
| `sig` | `string` | - |
| `pill_count` | `string` | - |
| `refills` | `string` | - |

##### Example (as JSON)

```json
{
  "name": "potassium chloride ER",
  "strength": "10 mEq Tab",
  "dose": "1 tab",
  "route": "PO",
  "sig": "daily",
  "pillCount": "#90",
  "refills": "Refill 3"
}
```

#### Diuretic

##### Class Name

`Diuretic`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `name` | `string` | - |
| `strength` | `string` | - |
| `dose` | `string` | - |
| `route` | `string` | - |
| `sig` | `string` | - |
| `pill_count` | `string` | - |
| `refills` | `string` | - |

##### Example (as JSON)

```json
{
  "name": "furosemide",
  "strength": "40 mg Tab",
  "dose": "1 tab",
  "route": "PO",
  "sig": "daily",
  "pillCount": "#90",
  "refills": "Refill 3"
}
```

#### BossCompany

##### Class Name

`BossCompany`

##### Inherits From

[`Company`](#company)

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `first_name` | `string` | - |
| `last_name` | `string` | - |
| `address_boss` | `string` | - |

##### Example (as JSON)

```json
{
  "company name": "APIMatic",
  "address": "nust",
  "cell number": "090078601",
  "first name": "Adeel",
  "last name": "Ali",
  "address_boss": "nust"
}
```

#### BetaBlocker

##### Class Name

`BetaBlocker`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `name` | `string` | - |
| `strength` | `string` | - |
| `dose` | `string` | - |
| `route` | `string` | - |
| `sig` | `string` | - |
| `pill_count` | `string` | - |
| `refills` | `string` | - |

##### Example (as JSON)

```json
{
  "name": "metoprolol tartrate",
  "strength": "25 mg Tab",
  "dose": "1 tab",
  "route": "PO",
  "sig": "daily",
  "pillCount": "#90",
  "refills": "Refill 3"
}
```

#### Anticoagulant

##### Class Name

`Anticoagulant`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `name` | `string` | - |
| `strength` | `string` | - |
| `dose` | `string` | - |
| `route` | `string` | - |
| `sig` | `string` | - |
| `pill_count` | `string` | - |
| `refills` | `string` | - |

##### Example (as JSON)

```json
{
  "name": "warfarin sodium",
  "strength": "3 mg Tab",
  "dose": "1 tab",
  "route": "PO",
  "sig": "daily",
  "pillCount": "#90",
  "refills": "Refill 3"
}
```

#### EmployeeComp

##### Class Name

`EmployeeComp`

##### Inherits From

[`Company`](#company)

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `first_name` | `string` | - |
| `last_name` | `string` | - |
| `id` | `string` | - |

##### Example (as JSON)

```json
{
  "company name": "APIMatic",
  "address": "nust",
  "cell number": "090078601",
  "first name": "Muhammad",
  "last name": "Farhan",
  "id": "123456"
}
```

#### Company

##### Class Name

`Company`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `company_name` | `string` |  | - |
| `address` | `string` |  | - |
| `cell_number` | `string` |  | - |
| `company` | `string` | Optional | - |

##### Example (as JSON)

```json
{
  "company name": "APIMatic",
  "address": "nust",
  "cell number": "090078601"
}
```

#### Attributes

##### Class Name

`Attributes`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `exclusive_maximum` | `bool` | - |
| `exclusive_minimum` | `bool` | - |
| `id` | `string` | - |

##### Example (as JSON)

```json
{
  "exclusiveMaximum": false,
  "exclusiveMinimum": false,
  "id": "5a9fcb01caacc310dc6bab51"
}
```

#### ResponseWithEnum

##### Class Name

`ResponseWithEnum`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `param_format` | [`ParamFormat`](#paramformat) | - |
| `optional` | `bool` | - |
| `mtype` | [`Type`](#type) | - |
| `constant` | `bool` | - |
| `is_array` | `bool` | - |
| `is_stream` | `bool` | - |
| `is_attribute` | `bool` | - |
| `is_map` | `bool` | - |
| `attributes` | [`Attributes`](#attributes) | - |
| `nullable` | `bool` | - |
| `id` | `string` | - |
| `name` | `string` | - |
| `description` | `string` | - |

##### Example (as JSON)

```json
{
  "paramFormat": "Template",
  "optional": false,
  "type": "Long",
  "constant": false,
  "isArray": false,
  "isStream": false,
  "isAttribute": false,
  "isMap": false,
  "attributes": {
    "exclusiveMaximum": false,
    "exclusiveMinimum": false,
    "id": "5a9fcb01caacc310dc6bab51"
  },
  "nullable": false,
  "id": "5a9fcb01caacc310dc6bab50",
  "name": "petId",
  "description": "ID of pet to update"
}
```

#### GlossDef

##### Class Name

`GlossDef`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `para` | `string` | - |
| `gloss_see_also` | `List of string` | - |

##### Example (as JSON)

```json
{
  "para": "A meta-markup language, used to create markup languages such as DocBook.",
  "GlossSeeAlso": [
    "GML",
    "XML"
  ]
}
```

#### GlossList

##### Class Name

`GlossList`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `gloss_entry` | [`GlossEntry`](#glossentry) | - |

##### Example (as JSON)

```json
{
  "GlossEntry": {
    "ID": "SGML",
    "SortAs": "SGML",
    "GlossTerm": "Standard Generalized Markup Language",
    "Acronym": "SGML",
    "Abbrev": "ISO 8879:1986",
    "GlossDef": {
      "para": "A meta-markup language, used to create markup languages such as DocBook.",
      "GlossSeeAlso": [
        "GML",
        "XML"
      ]
    },
    "GlossSee": "markup"
  }
}
```

#### GlossDiv

##### Class Name

`GlossDiv`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `title` | `string` | - |
| `gloss_list` | [`GlossList`](#glosslist) | - |

##### Example (as JSON)

```json
{
  "title": "S",
  "GlossList": {
    "GlossEntry": {
      "ID": "SGML",
      "SortAs": "SGML",
      "GlossTerm": "Standard Generalized Markup Language",
      "Acronym": "SGML",
      "Abbrev": "ISO 8879:1986",
      "GlossDef": {
        "para": "A meta-markup language, used to create markup languages such as DocBook.",
        "GlossSeeAlso": [
          "GML",
          "XML"
        ]
      },
      "GlossSee": "markup"
    }
  }
}
```

#### Glossary

##### Class Name

`Glossary`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `title` | `string` | - |
| `gloss_div` | [`GlossDiv`](#glossdiv) | - |

##### Example (as JSON)

```json
{
  "title": "example glossary",
  "GlossDiv": {
    "title": "S",
    "GlossList": {
      "GlossEntry": {
        "ID": "SGML",
        "SortAs": "SGML",
        "GlossTerm": "Standard Generalized Markup Language",
        "Acronym": "SGML",
        "Abbrev": "ISO 8879:1986",
        "GlossDef": {
          "para": "A meta-markup language, used to create markup languages such as DocBook.",
          "GlossSeeAlso": [
            "GML",
            "XML"
          ]
        },
        "GlossSee": "markup"
      }
    }
  }
}
```

#### Imaging

##### Class Name

`Imaging`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `name` | `string` | - |
| `time` | `string` | - |
| `location` | `string` | - |

##### Example (as JSON)

```json
{
  "name": "Chest X-Ray",
  "time": "Today",
  "location": "Main Hospital Radiology"
}
```

#### Lab

##### Class Name

`Lab`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `name` | `string` | - |
| `time` | `string` | - |
| `location` | `string` | - |

##### Example (as JSON)

```json
{
  "name": "Arterial Blood Gas",
  "time": "Today",
  "location": "Main Hospital Lab"
}
```

#### Antianginal

##### Class Name

`Antianginal`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `name` | `string` | - |
| `strength` | `string` | - |
| `dose` | `string` | - |
| `route` | `string` | - |
| `sig` | `string` | - |
| `pill_count` | `string` | - |
| `refills` | `string` | - |

##### Example (as JSON)

```json
{
  "name": "nitroglycerin",
  "strength": "0.4 mg Sublingual Tab",
  "dose": "1 tab",
  "route": "SL",
  "sig": "q15min PRN",
  "pillCount": "#30",
  "refills": "Refill 1"
}
```

#### AceInhibitor

##### Class Name

`AceInhibitor`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `name` | `string` | - |
| `strength` | `string` | - |
| `dose` | `string` | - |
| `route` | `string` | - |
| `sig` | `string` | - |
| `pill_count` | `string` | - |
| `refills` | `string` | - |

##### Example (as JSON)

```json
{
  "name": "lisinopril",
  "strength": "10 mg Tab",
  "dose": "1 tab",
  "route": "PO",
  "sig": "daily",
  "pillCount": "#90",
  "refills": "Refill 3"
}
```

#### Medication

##### Class Name

`Medication`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `ace_inhibitors` | [`List of AceInhibitor`](#aceinhibitor) | - |
| `antianginal` | [`List of Antianginal`](#antianginal) | - |
| `anticoagulants` | [`List of Anticoagulant`](#anticoagulant) | - |
| `beta_blocker` | [`List of BetaBlocker`](#betablocker) | - |
| `diuretic` | [`List of Diuretic`](#diuretic) | - |
| `mineral` | [`List of Mineral`](#mineral) | - |

##### Example (as JSON)

```json
{
  "aceInhibitors": [
    {
      "name": "lisinopril",
      "strength": "10 mg Tab",
      "dose": "1 tab",
      "route": "PO",
      "sig": "daily",
      "pillCount": "#90",
      "refills": "Refill 3"
    }
  ],
  "antianginal": [
    {
      "name": "nitroglycerin",
      "strength": "0.4 mg Sublingual Tab",
      "dose": "1 tab",
      "route": "SL",
      "sig": "q15min PRN",
      "pillCount": "#30",
      "refills": "Refill 1"
    }
  ],
  "anticoagulants": [
    {
      "name": "warfarin sodium",
      "strength": "3 mg Tab",
      "dose": "1 tab",
      "route": "PO",
      "sig": "daily",
      "pillCount": "#90",
      "refills": "Refill 3"
    }
  ],
  "betaBlocker": [
    {
      "name": "metoprolol tartrate",
      "strength": "25 mg Tab",
      "dose": "1 tab",
      "route": "PO",
      "sig": "daily",
      "pillCount": "#90",
      "refills": "Refill 3"
    }
  ],
  "diuretic": [
    {
      "name": "furosemide",
      "strength": "40 mg Tab",
      "dose": "1 tab",
      "route": "PO",
      "sig": "daily",
      "pillCount": "#90",
      "refills": "Refill 3"
    }
  ],
  "mineral": [
    {
      "name": "potassium chloride ER",
      "strength": "10 mEq Tab",
      "dose": "1 tab",
      "route": "PO",
      "sig": "daily",
      "pillCount": "#90",
      "refills": "Refill 3"
    }
  ]
}
```

#### Complex1

##### Class Name

`Complex1`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `medications` | [`List of Medication`](#medication) | - |
| `labs` | [`List of Lab`](#lab) | - |
| `imaging` | [`List of Imaging`](#imaging) | - |

##### Example (as JSON)

```json
{
  "medications": [
    {
      "aceInhibitors": [
        {
          "name": "lisinopril",
          "strength": "10 mg Tab",
          "dose": "1 tab",
          "route": "PO",
          "sig": "daily",
          "pillCount": "#90",
          "refills": "Refill 3"
        }
      ],
      "antianginal": [
        {
          "name": "nitroglycerin",
          "strength": "0.4 mg Sublingual Tab",
          "dose": "1 tab",
          "route": "SL",
          "sig": "q15min PRN",
          "pillCount": "#30",
          "refills": "Refill 1"
        }
      ],
      "anticoagulants": [
        {
          "name": "warfarin sodium",
          "strength": "3 mg Tab",
          "dose": "1 tab",
          "route": "PO",
          "sig": "daily",
          "pillCount": "#90",
          "refills": "Refill 3"
        }
      ],
      "betaBlocker": [
        {
          "name": "metoprolol tartrate",
          "strength": "25 mg Tab",
          "dose": "1 tab",
          "route": "PO",
          "sig": "daily",
          "pillCount": "#90",
          "refills": "Refill 3"
        }
      ],
      "diuretic": [
        {
          "name": "furosemide",
          "strength": "40 mg Tab",
          "dose": "1 tab",
          "route": "PO",
          "sig": "daily",
          "pillCount": "#90",
          "refills": "Refill 3"
        }
      ],
      "mineral": [
        {
          "name": "potassium chloride ER",
          "strength": "10 mEq Tab",
          "dose": "1 tab",
          "route": "PO",
          "sig": "daily",
          "pillCount": "#90",
          "refills": "Refill 3"
        }
      ]
    }
  ],
  "labs": [
    {
      "name": "Arterial Blood Gas",
      "time": "Today",
      "location": "Main Hospital Lab"
    },
    {
      "name": "BMP",
      "time": "Today",
      "location": "Primary Care Clinic"
    },
    {
      "name": "BNP",
      "time": "3 Weeks",
      "location": "Primary Care Clinic"
    },
    {
      "name": "BUN",
      "time": "1 Year",
      "location": "Primary Care Clinic"
    },
    {
      "name": "Cardiac Enzymes",
      "time": "Today",
      "location": "Primary Care Clinic"
    },
    {
      "name": "CBC",
      "time": "1 Year",
      "location": "Primary Care Clinic"
    },
    {
      "name": "Creatinine",
      "time": "1 Year",
      "location": "Main Hospital Lab"
    },
    {
      "name": "Electrolyte Panel",
      "time": "1 Year",
      "location": "Primary Care Clinic"
    },
    {
      "name": "Glucose",
      "time": "1 Year",
      "location": "Main Hospital Lab"
    },
    {
      "name": "PT/INR",
      "time": "3 Weeks",
      "location": "Primary Care Clinic"
    },
    {
      "name": "PTT",
      "time": "3 Weeks",
      "location": "Coumadin Clinic"
    },
    {
      "name": "TSH",
      "time": "1 Year",
      "location": "Primary Care Clinic"
    }
  ],
  "imaging": [
    {
      "name": "Chest X-Ray",
      "time": "Today",
      "location": "Main Hospital Radiology"
    },
    {
      "name": "Chest X-Ray",
      "time": "Today",
      "location": "Main Hospital Radiology"
    },
    {
      "name": "Chest X-Ray",
      "time": "Today",
      "location": "Main Hospital Radiology"
    }
  ]
}
```

#### Complex2

##### Class Name

`Complex2`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `glossary` | [`Glossary`](#glossary) | - |

##### Example (as JSON)

```json
{
  "glossary": {
    "title": "example glossary",
    "GlossDiv": {
      "title": "S",
      "GlossList": {
        "GlossEntry": {
          "ID": "SGML",
          "SortAs": "SGML",
          "GlossTerm": "Standard Generalized Markup Language",
          "Acronym": "SGML",
          "Abbrev": "ISO 8879:1986",
          "GlossDef": {
            "para": "A meta-markup language, used to create markup languages such as DocBook.",
            "GlossSeeAlso": [
              "GML",
              "XML"
            ]
          },
          "GlossSee": "markup"
        }
      }
    }
  }
}
```

#### Advanced

##### Class Name

`Advanced`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `tags` | `List of string` | - |
| `attachments` | `int` | - |
| `required_signatures` | `int` | - |
| `get_social_security_number` | `bool` | - |
| `time_to_live` | [`TimeToLive`](#timetolive) | - |

##### Example (as JSON)

```json
{
  "tags": [
    "develop",
    "fun_with_documents"
  ],
  "attachments": 0,
  "requiredSignatures": 0,
  "getSocialSecurityNumber": false,
  "timeToLive": {
    "deadline": "2018-06-29T14:57:25Z",
    "deleteAfterHours": 1
  }
}
```

#### DataToSign

##### Class Name

`DataToSign`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `file_name` | `string` | - |
| `convert_to_pdf` | `bool` | - |

##### Example (as JSON)

```json
{
  "fileName": "sample.txt",
  "convertToPDF": false
}
```

#### ContactDetails

##### Class Name

`ContactDetails`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `email` | `string` | - |
| `url` | `string` | - |

##### Example (as JSON)

```json
{
  "email": "test@test.com",
  "url": "https://idfy.io"
}
```

#### Styling

##### Class Name

`Styling`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `color_theme` | `string` | - |
| `spinner` | `string` | - |

##### Example (as JSON)

```json
{
  "colorTheme": "Pink",
  "spinner": "Cubes"
}
```

#### Dialogs

##### Class Name

`Dialogs`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `before` | [`Before`](#before) | - |

##### Example (as JSON)

```json
{
  "before": {
    "useCheckBox": false,
    "title": "Info",
    "message": "Please read the contract on the next pages carefully. Pay some extra attention to paragraph 5."
  }
}
```

#### SignatureType

##### Class Name

`SignatureType`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `mechanism` | `string` | - |
| `on_eaccept_use_hand_written_signature` | `bool` | - |

##### Example (as JSON)

```json
{
  "mechanism": "pkisignature",
  "onEacceptUseHandWrittenSignature": false
}
```

#### RedirectSettings

##### Class Name

`RedirectSettings`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `redirect_mode` | `string` | - |

##### Example (as JSON)

```json
{
  "redirectMode": "donot_redirect"
}
```

#### TimeToLive

##### Class Name

`TimeToLive`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `deadline` | `string` | - |
| `delete_after_hours` | `int` | - |

##### Example (as JSON)

```json
{
  "deadline": "2018-06-29T14:57:25Z",
  "deleteAfterHours": 1
}
```

#### Status

##### Class Name

`Status`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `document_status` | `string` | - |
| `completed_packages` | `List of string` | - |
| `attachment_packages` | `object` | - |

##### Example (as JSON)

```json
{
  "documentStatus": "unsigned",
  "completedPackages": [],
  "attachmentPackages": {}
}
```

#### Before

##### Class Name

`Before`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `use_check_box` | `bool` | - |
| `title` | `string` | - |
| `message` | `string` | - |

##### Example (as JSON)

```json
{
  "useCheckBox": false,
  "title": "Info",
  "message": "Please read the contract on the next pages carefully. Pay some extra attention to paragraph 5."
}
```

#### Ui

##### Class Name

`Ui`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `dialogs` | [`Dialogs`](#dialogs) | - |
| `language` | [`LanguageEnum`](#languageenum) | - |
| `styling` | [`Styling`](#styling) | - |

##### Example (as JSON)

```json
{
  "dialogs": {
    "before": {
      "useCheckBox": false,
      "title": "Info",
      "message": "Please read the contract on the next pages carefully. Pay some extra attention to paragraph 5."
    }
  },
  "language": "EN",
  "styling": {
    "colorTheme": "Pink",
    "spinner": "Cubes"
  }
}
```

#### Complex3

##### Class Name

`Complex3`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `document_id` | `string` | - |
| `signers` | [`List of Signer`](#signer) | - |
| `status` | [`Status`](#status) | - |
| `title` | `string` | - |
| `description` | `string` | - |
| `external_id` | `string` | - |
| `data_to_sign` | [`DataToSign`](#datatosign) | - |
| `contact_details` | [`ContactDetails`](#contactdetails) | - |
| `advanced` | [`Advanced`](#advanced) | - |

##### Example (as JSON)

```json
{
  "documentId": "099cceda-38a8-4b01-87b9-a8f2007675d6",
  "signers": [
    {
      "id": "1bef97d1-0704-4eb2-a490-a8f2007675db",
      "url": "https://sign-test.idfy.io/start?jwt=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzM4NCJ9. .Dyy2RSeR6dmU8qxOEi-2gEX3Gg7wry6JhkZIWOuADDdu5jJWidQLcxfJn_qAHNpb",
      "links": [],
      "externalSignerId": "uoiahsd321982983jhrmnec2wsadm32",
      "redirectSettings": {
        "redirectMode": "donot_redirect"
      },
      "signatureType": {
        "mechanism": "pkisignature",
        "onEacceptUseHandWrittenSignature": false
      },
      "ui": {
        "dialogs": {
          "before": {
            "useCheckBox": false,
            "title": "Info",
            "message": "Please read the contract on the next pages carefully. Pay some extra attention to paragraph 5."
          }
        },
        "language": "EN",
        "styling": {
          "colorTheme": "Pink",
          "spinner": "Cubes"
        }
      },
      "tags": [],
      "order": 0,
      "required": false
    }
  ],
  "status": {
    "documentStatus": "unsigned",
    "completedPackages": [],
    "attachmentPackages": {}
  },
  "title": "Test document",
  "description": "This is an important document",
  "externalId": "ae7b9ca7-3839-4e0d-a070-9f14bffbbf55",
  "dataToSign": {
    "fileName": "sample.txt",
    "convertToPDF": false
  },
  "contactDetails": {
    "email": "test@test.com",
    "url": "https://idfy.io"
  },
  "advanced": {
    "tags": [
      "develop",
      "fun_with_documents"
    ],
    "attachments": 0,
    "requiredSignatures": 0,
    "getSocialSecurityNumber": false,
    "timeToLive": {
      "deadline": "2018-06-29T14:57:25Z",
      "deleteAfterHours": 1
    }
  }
}
```

#### Signer

##### Class Name

`Signer`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `id` | `string` | - |
| `url` | `string` | - |
| `links` | `List of string` | - |
| `external_signer_id` | `string` | - |
| `redirect_settings` | [`RedirectSettings`](#redirectsettings) | - |
| `signature_type` | [`SignatureType`](#signaturetype) | - |
| `ui` | [`Ui`](#ui) | - |
| `tags` | `List of string` | - |
| `order` | `int` | - |
| `required` | `bool` | - |

##### Example (as JSON)

```json
{
  "id": "1bef97d1-0704-4eb2-a490-a8f2007675db",
  "url": "https://sign-test.idfy.io/start?jwt=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzM4NCJ9. .Dyy2RSeR6dmU8qxOEi-2gEX3Gg7wry6JhkZIWOuADDdu5jJWidQLcxfJn_qAHNpb",
  "links": [],
  "externalSignerId": "uoiahsd321982983jhrmnec2wsadm32",
  "redirectSettings": {
    "redirectMode": "donot_redirect"
  },
  "signatureType": {
    "mechanism": "pkisignature",
    "onEacceptUseHandWrittenSignature": false
  },
  "ui": {
    "dialogs": {
      "before": {
        "useCheckBox": false,
        "title": "Info",
        "message": "Please read the contract on the next pages carefully. Pay some extra attention to paragraph 5."
      }
    },
    "language": "EN",
    "styling": {
      "colorTheme": "Pink",
      "spinner": "Cubes"
    }
  },
  "tags": [],
  "order": 0,
  "required": false
}
```

#### Complex5

##### Class Name

`Complex5`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `response_data` | [`ResponseData`](#responsedata) |  | - |
| `response_details` | `string` | Optional | - |
| `response_status` | `int` |  | - |

##### Example (as JSON)

```json
{
  "responseData": {
    "feed": {
      "feedUrl": "http://ramrojob.com/feed",
      "title": "Ramro Job",
      "link": "http://ramrojob.com",
      "author": "",
      "description": "...your pathway to success",
      "type": "rss20",
      "entries": [
        {
          "title": "Monitoring and Evaluation Specialist Wanted at GRM International",
          "link": "http://ramrojob.com/job/2013/05/12/monitoring-and-evaluation-specialist-wanted-at-grm-international.html",
          "author": "Bandana Aryal",
          "publishedDate": "Sun, 12 May 2013 01:10:24 -0700",
          "contentSnippet": "Key Responsibilities Under direction of the Team Leader, responsible for the design and roll out of programme M&#38;E plan, ...",
          "content": "<p><strong>Key Responsibilities</strong></p>\n<ul>\n<li>Under direction of the Team Leader, responsible for the design and roll out of programme M&amp;E plan, including design of the logframe and key performance indicators.</li>\n<li>Track programme progress against indicators and ensure early identification of any areas requiring remedial action.</li>\n<li>Carry out site visits and provide M&amp;E support and training for local partners.</li>\n<li>Harmonise programme monitoring indicators and systems with national M&amp;E systems.</li>\n<li>Promote use of data to inform decision making and link evidence-based approaches to achievement of results.</li>\n<li>Support operations research and specialised studies, such as client satisfaction, cost-effectiveness, and impact evaluation.</li>\n<li>Solicit and manage local data collection and research teams, as needed.</li>\n<li>Contribute to the preparation of regular progress reports, technical deliverables, presentations, and annual work plans.</li>\n</ul>\n<p><strong>Qualifications</strong></p>\n<ul>\n<li>Seven or more years of experience monitoring and evaluating reproductive health and family planning programmes, including promoting use of data for decision-making.</li>\n<li>Strong technical grasp of relevant health issues: sexual and reproductive health; family planning; maternal, new-born, and child health; HIV and AIDS; and health equity.</li>\n<li>Understanding of health market dynamics and the health system in Nepal.</li>\n<li>Demonstrated experience working with government, private sector, and nongovernmental health sector partners in Nepal, at national and decentralised levels.</li>\n<li>Experience supporting DFID, European Union, USAID, World Bank, or other donor-funded or government health programmes.</li>\n<li>Strong quantitative and qualitative research and analysis skills.</li>\n<li>Demonstrated experience with computerised management information systems, databases, MS Office, and other relevant skills.</li>\n<li>Ability to graphically present data in ways that engage and influence target audiences.</li>\n<li>Knowledge of in-country and international guidelines pertaining to research ethics.</li>\n<li>Strong personal qualities, including integrity, commitment to excellence, equality, openness, inclusiveness, and collegiality.</li>\n<li>Excellent written and spoken English required, local languages are a distinct advantage.</li>\n<li>Advanced degree/s in relevant discipline preferred.</li>\n<li>Nepali nationals strongly encouraged to apply.</li>\n</ul>\n<p>The post <a href=\"http://ramrojob.com/job/2013/05/12/monitoring-and-evaluation-specialist-wanted-at-grm-international.html\">Monitoring and Evaluation Specialist Wanted at GRM International</a> appeared first on <a href=\"http://ramrojob.com\">Ramro Job</a>.</p>",
          "categories": [
            "Uncategorized"
          ]
        },
        {
          "title": "Director of Finance and Admin Wanted at Abt Associates",
          "link": "http://ramrojob.com/job/2013/05/12/director-of-finance-and-admin-wanted-at-abt-associates.html",
          "author": "Bandana Aryal",
          "publishedDate": "Sun, 12 May 2013 01:02:28 -0700",
          "contentSnippet": "Job Responsibilities: Abt Associates seeks a Director of Finance and Administration for an upcoming DFID-funded family planning ...",
          "content": "<p><strong>Job Responsibilities:</strong></p>\n<p>Abt Associates seeks a Director of Finance and Administration for an upcoming DFID-funded family planning program in Nepal. The initiative will work with the Ministry of Health and Population to increase use of modern high-quality family planning methods by the most vulnerable and excluded women by supply innovative and high quality family planning services. The program will also work with the Ministry of Health and Population to ensure better choices and availabilites of reproductive health commodities.</p>\n<p>The Director of Finance and Administration will be responsible for the management of the contract, procurement, subcontracting, financial management and reporting, and general administrative support of the program. S/he will develop and track budgets, manage payroll and vendor relations, and control all financial transactions and reporting, both for the client and for Abt Associates headquarters.</p>\n<p>Specific responsibilities will include:</p>\n<ul>\n<li>Ensure compliance with terms and references in the contract;</li>\n<li>Develop and implement financial and administrative policies and procedures that meet project requirements and donor regulations;</li>\n<li>Create and maintain financial reporting and tracking systems, and provide financial performance updates on project activities;</li>\n<li>Prepare budgets and revenue plans for project programming and corporate reporting;</li>\n<li>Oversee financial and HR administration of project (purchase requisitions, consulting agreements, vendor invoices, client invoices, payroll etc.);</li>\n<li>Manage vendors and subcontractors in compliance with Abt and DfID policies and regulations;</li>\n<li>Supervise all financial and administrative staff;</li>\n<li>Provide training to field staff on project procedures as well as building skill-levels of project staff in the area of finance, administration, and project management.</li>\n</ul>\n<p><strong>Skills Prerequisites:</strong></p>\n<ul>\n<li>Bachelor�s Degree (minimum) or master�s degree (preferred) in Business, Finance, Accounting or other relevant field;</li>\n<li>10 years of experience in administration, project management and/or financial management;</li>\n<li>5 years of experience working with international donors in a development setting;</li>\n<li>Experience with DfID contracts desirable;</li>\n<li>Strong analytical and computer skills, with emphasis on budgeting and financial analysis;</li>\n<li>Excellent inter-personal, communication and organizational skills;</li>\n<li>Capabilities in Nepali or other South Asian languages are desirable.</li>\n</ul>\n<p>The post <a href=\"http://ramrojob.com/job/2013/05/12/director-of-finance-and-admin-wanted-at-abt-associates.html\">Director of Finance and Admin Wanted at Abt Associates</a> appeared first on <a href=\"http://ramrojob.com\">Ramro Job</a>.</p>",
          "categories": [
            "Uncategorized"
          ]
        },
        {
          "title": "Technical Director Wanted at Family Planning Nepal",
          "link": "http://ramrojob.com/job/2013/05/12/technical-director-wanted-at-family-planning-nepal.html",
          "author": "Bandana Aryal",
          "publishedDate": "Sun, 12 May 2013 00:57:03 -0700",
          "contentSnippet": "Skills Prerequisites: Masters Degree (minimum) in Public Health, Business Administration or related relevant discipline Ten ...",
          "content": "<p><strong>Skills Prerequisites:</strong></p>\n<ul>\n<li>Masters Degree (minimum) in Public Health, Business Administration or related relevant discipline</li>\n<li>Ten years (10) of relevant professional experience, including sales or marketing, and strong business acumen in areas of business process and analysis would be highly valued</li>\n<li>Eight (8) years experience working in health sector projects or initiatives involving multiple stakeholder groups, including NGOs and the private health sector</li>\n<li>Successful prior experience in social marketing or franchising</li>\n<li>Proven track record of building and sustaining effective partnerships, advocating effectively and communicating to various constituencies</li>\n<li>Ability to coordinate in a dynamic environment</li>\n<li>Substantial experience in building capacity in the non-state/private sector</li>\n<li>Ability to independently plan and execute complex tasks while addressing daily management details and remaining organized and focused on long-term deadlines and strategies</li>\n<li>Solid professional reputation and strong, demonstrated interpersonal skills</li>\n<li>Professional working experience in Nepal desirable</li>\n<li>Fluency in Nepali desirable</li>\n<li>Excellent written and oral presentation skills in English</li>\n</ul>\n<p>The post <a href=\"http://ramrojob.com/job/2013/05/12/technical-director-wanted-at-family-planning-nepal.html\">Technical Director Wanted at Family Planning Nepal</a> appeared first on <a href=\"http://ramrojob.com\">Ramro Job</a>.</p>",
          "categories": [
            "Uncategorized"
          ]
        },
        {
          "title": "Monitoring and Evaluation Analyst Wanted at UN Women",
          "link": "http://ramrojob.com/job/2013/05/12/monitoring-and-evaluation-analyst-wanted-at-un-women.html",
          "author": "Bandana Aryal",
          "publishedDate": "Sun, 12 May 2013 00:46:37 -0700",
          "contentSnippet": "Core Competencies Knowledge of current practices in the area of monitoring and evaluation, knowledge management Promotes the ...",
          "content": "<p><b>Core Competencies</b></p>\n<ul>\n<li>Knowledge of current practices in the area of monitoring and evaluation, knowledge management</li>\n<li>Promotes the vision, mission, and strategic goals of UN Women;</li>\n<li>Displays cultural, gender, religion, race, nationality and age sensitivity and adaptability</li>\n<li>Fostering innovation and empowerment</li>\n<li>Working in teams at all levels</li>\n<li>Communicating information and ideas/knowledge sharing</li>\n<li>Analytical and strategic thinking/results orientation/commitment to Excellence</li>\n</ul>\n<p><span style=\"text-decoration:underline\"><strong>Qualifications and Experience:</strong></span></p>\n<ul>\n<li>Master�s Degree in Economics, Management, Rural Development, Social Sciences, or related field. Additional certification in statistics, MIS management and Monitoring and Evaluation will be considered as an asset.</li>\n<li>Two years of relevant professional experience in the field of rights based monitoring and evaluation;</li>\n<li>Experience in the management of gender equality and women�s empowerment programmes or analytic work in gender and development, gender analysis and/or human rights;</li>\n<li> Good knowledge of rights-based approach and result-based management.</li>\n<li> Experience related to UN Women�s mandate and activities would be an added advantage;</li>\n<li> Sound knowledge of international standards on human rights, women�s rights and related instruments;</li>\n<li>A proven ability to liaise with a myriad of stakeholders and partners, including government, civil society, international organizations and grassroots organizations</li>\n</ul>\n<p>The post <a href=\"http://ramrojob.com/job/2013/05/12/monitoring-and-evaluation-analyst-wanted-at-un-women.html\">Monitoring and Evaluation Analyst Wanted at UN Women</a> appeared first on <a href=\"http://ramrojob.com\">Ramro Job</a>.</p>",
          "categories": [
            "The Himalayan Times"
          ]
        }
      ]
    }
  },
  "responseStatus": 200
}
```

#### ResponseData

##### Class Name

`ResponseData`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `feed` | [`Feed`](#feed) | - |

##### Example (as JSON)

```json
{
  "feed": {
    "feedUrl": "http://ramrojob.com/feed",
    "title": "Ramro Job",
    "link": "http://ramrojob.com",
    "author": "",
    "description": "...your pathway to success",
    "type": "rss20",
    "entries": [
      {
        "title": "Monitoring and Evaluation Specialist Wanted at GRM International",
        "link": "http://ramrojob.com/job/2013/05/12/monitoring-and-evaluation-specialist-wanted-at-grm-international.html",
        "author": "Bandana Aryal",
        "publishedDate": "Sun, 12 May 2013 01:10:24 -0700",
        "contentSnippet": "Key Responsibilities Under direction of the Team Leader, responsible for the design and roll out of programme M&#38;E plan, ...",
        "content": "<p><strong>Key Responsibilities</strong></p>\n<ul>\n<li>Under direction of the Team Leader, responsible for the design and roll out of programme M&amp;E plan, including design of the logframe and key performance indicators.</li>\n<li>Track programme progress against indicators and ensure early identification of any areas requiring remedial action.</li>\n<li>Carry out site visits and provide M&amp;E support and training for local partners.</li>\n<li>Harmonise programme monitoring indicators and systems with national M&amp;E systems.</li>\n<li>Promote use of data to inform decision making and link evidence-based approaches to achievement of results.</li>\n<li>Support operations research and specialised studies, such as client satisfaction, cost-effectiveness, and impact evaluation.</li>\n<li>Solicit and manage local data collection and research teams, as needed.</li>\n<li>Contribute to the preparation of regular progress reports, technical deliverables, presentations, and annual work plans.</li>\n</ul>\n<p><strong>Qualifications</strong></p>\n<ul>\n<li>Seven or more years of experience monitoring and evaluating reproductive health and family planning programmes, including promoting use of data for decision-making.</li>\n<li>Strong technical grasp of relevant health issues: sexual and reproductive health; family planning; maternal, new-born, and child health; HIV and AIDS; and health equity.</li>\n<li>Understanding of health market dynamics and the health system in Nepal.</li>\n<li>Demonstrated experience working with government, private sector, and nongovernmental health sector partners in Nepal, at national and decentralised levels.</li>\n<li>Experience supporting DFID, European Union, USAID, World Bank, or other donor-funded or government health programmes.</li>\n<li>Strong quantitative and qualitative research and analysis skills.</li>\n<li>Demonstrated experience with computerised management information systems, databases, MS Office, and other relevant skills.</li>\n<li>Ability to graphically present data in ways that engage and influence target audiences.</li>\n<li>Knowledge of in-country and international guidelines pertaining to research ethics.</li>\n<li>Strong personal qualities, including integrity, commitment to excellence, equality, openness, inclusiveness, and collegiality.</li>\n<li>Excellent written and spoken English required, local languages are a distinct advantage.</li>\n<li>Advanced degree/s in relevant discipline preferred.</li>\n<li>Nepali nationals strongly encouraged to apply.</li>\n</ul>\n<p>The post <a href=\"http://ramrojob.com/job/2013/05/12/monitoring-and-evaluation-specialist-wanted-at-grm-international.html\">Monitoring and Evaluation Specialist Wanted at GRM International</a> appeared first on <a href=\"http://ramrojob.com\">Ramro Job</a>.</p>",
        "categories": [
          "Uncategorized"
        ]
      },
      {
        "title": "Director of Finance and Admin Wanted at Abt Associates",
        "link": "http://ramrojob.com/job/2013/05/12/director-of-finance-and-admin-wanted-at-abt-associates.html",
        "author": "Bandana Aryal",
        "publishedDate": "Sun, 12 May 2013 01:02:28 -0700",
        "contentSnippet": "Job Responsibilities: Abt Associates seeks a Director of Finance and Administration for an upcoming DFID-funded family planning ...",
        "content": "<p><strong>Job Responsibilities:</strong></p>\n<p>Abt Associates seeks a Director of Finance and Administration for an upcoming DFID-funded family planning program in Nepal. The initiative will work with the Ministry of Health and Population to increase use of modern high-quality family planning methods by the most vulnerable and excluded women by supply innovative and high quality family planning services. The program will also work with the Ministry of Health and Population to ensure better choices and availabilites of reproductive health commodities.</p>\n<p>The Director of Finance and Administration will be responsible for the management of the contract, procurement, subcontracting, financial management and reporting, and general administrative support of the program. S/he will develop and track budgets, manage payroll and vendor relations, and control all financial transactions and reporting, both for the client and for Abt Associates headquarters.</p>\n<p>Specific responsibilities will include:</p>\n<ul>\n<li>Ensure compliance with terms and references in the contract;</li>\n<li>Develop and implement financial and administrative policies and procedures that meet project requirements and donor regulations;</li>\n<li>Create and maintain financial reporting and tracking systems, and provide financial performance updates on project activities;</li>\n<li>Prepare budgets and revenue plans for project programming and corporate reporting;</li>\n<li>Oversee financial and HR administration of project (purchase requisitions, consulting agreements, vendor invoices, client invoices, payroll etc.);</li>\n<li>Manage vendors and subcontractors in compliance with Abt and DfID policies and regulations;</li>\n<li>Supervise all financial and administrative staff;</li>\n<li>Provide training to field staff on project procedures as well as building skill-levels of project staff in the area of finance, administration, and project management.</li>\n</ul>\n<p><strong>Skills Prerequisites:</strong></p>\n<ul>\n<li>Bachelor�s Degree (minimum) or master�s degree (preferred) in Business, Finance, Accounting or other relevant field;</li>\n<li>10 years of experience in administration, project management and/or financial management;</li>\n<li>5 years of experience working with international donors in a development setting;</li>\n<li>Experience with DfID contracts desirable;</li>\n<li>Strong analytical and computer skills, with emphasis on budgeting and financial analysis;</li>\n<li>Excellent inter-personal, communication and organizational skills;</li>\n<li>Capabilities in Nepali or other South Asian languages are desirable.</li>\n</ul>\n<p>The post <a href=\"http://ramrojob.com/job/2013/05/12/director-of-finance-and-admin-wanted-at-abt-associates.html\">Director of Finance and Admin Wanted at Abt Associates</a> appeared first on <a href=\"http://ramrojob.com\">Ramro Job</a>.</p>",
        "categories": [
          "Uncategorized"
        ]
      },
      {
        "title": "Technical Director Wanted at Family Planning Nepal",
        "link": "http://ramrojob.com/job/2013/05/12/technical-director-wanted-at-family-planning-nepal.html",
        "author": "Bandana Aryal",
        "publishedDate": "Sun, 12 May 2013 00:57:03 -0700",
        "contentSnippet": "Skills Prerequisites: Masters Degree (minimum) in Public Health, Business Administration or related relevant discipline Ten ...",
        "content": "<p><strong>Skills Prerequisites:</strong></p>\n<ul>\n<li>Masters Degree (minimum) in Public Health, Business Administration or related relevant discipline</li>\n<li>Ten years (10) of relevant professional experience, including sales or marketing, and strong business acumen in areas of business process and analysis would be highly valued</li>\n<li>Eight (8) years experience working in health sector projects or initiatives involving multiple stakeholder groups, including NGOs and the private health sector</li>\n<li>Successful prior experience in social marketing or franchising</li>\n<li>Proven track record of building and sustaining effective partnerships, advocating effectively and communicating to various constituencies</li>\n<li>Ability to coordinate in a dynamic environment</li>\n<li>Substantial experience in building capacity in the non-state/private sector</li>\n<li>Ability to independently plan and execute complex tasks while addressing daily management details and remaining organized and focused on long-term deadlines and strategies</li>\n<li>Solid professional reputation and strong, demonstrated interpersonal skills</li>\n<li>Professional working experience in Nepal desirable</li>\n<li>Fluency in Nepali desirable</li>\n<li>Excellent written and oral presentation skills in English</li>\n</ul>\n<p>The post <a href=\"http://ramrojob.com/job/2013/05/12/technical-director-wanted-at-family-planning-nepal.html\">Technical Director Wanted at Family Planning Nepal</a> appeared first on <a href=\"http://ramrojob.com\">Ramro Job</a>.</p>",
        "categories": [
          "Uncategorized"
        ]
      },
      {
        "title": "Monitoring and Evaluation Analyst Wanted at UN Women",
        "link": "http://ramrojob.com/job/2013/05/12/monitoring-and-evaluation-analyst-wanted-at-un-women.html",
        "author": "Bandana Aryal",
        "publishedDate": "Sun, 12 May 2013 00:46:37 -0700",
        "contentSnippet": "Core Competencies Knowledge of current practices in the area of monitoring and evaluation, knowledge management Promotes the ...",
        "content": "<p><b>Core Competencies</b></p>\n<ul>\n<li>Knowledge of current practices in the area of monitoring and evaluation, knowledge management</li>\n<li>Promotes the vision, mission, and strategic goals of UN Women;</li>\n<li>Displays cultural, gender, religion, race, nationality and age sensitivity and adaptability</li>\n<li>Fostering innovation and empowerment</li>\n<li>Working in teams at all levels</li>\n<li>Communicating information and ideas/knowledge sharing</li>\n<li>Analytical and strategic thinking/results orientation/commitment to Excellence</li>\n</ul>\n<p><span style=\"text-decoration:underline\"><strong>Qualifications and Experience:</strong></span></p>\n<ul>\n<li>Master�s Degree in Economics, Management, Rural Development, Social Sciences, or related field. Additional certification in statistics, MIS management and Monitoring and Evaluation will be considered as an asset.</li>\n<li>Two years of relevant professional experience in the field of rights based monitoring and evaluation;</li>\n<li>Experience in the management of gender equality and women�s empowerment programmes or analytic work in gender and development, gender analysis and/or human rights;</li>\n<li> Good knowledge of rights-based approach and result-based management.</li>\n<li> Experience related to UN Women�s mandate and activities would be an added advantage;</li>\n<li> Sound knowledge of international standards on human rights, women�s rights and related instruments;</li>\n<li>A proven ability to liaise with a myriad of stakeholders and partners, including government, civil society, international organizations and grassroots organizations</li>\n</ul>\n<p>The post <a href=\"http://ramrojob.com/job/2013/05/12/monitoring-and-evaluation-analyst-wanted-at-un-women.html\">Monitoring and Evaluation Analyst Wanted at UN Women</a> appeared first on <a href=\"http://ramrojob.com\">Ramro Job</a>.</p>",
        "categories": [
          "The Himalayan Times"
        ]
      }
    ]
  }
}
```

#### Feed

##### Class Name

`Feed`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `feed_url` | `string` | - |
| `title` | `string` | - |
| `link` | `string` | - |
| `author` | `string` | - |
| `description` | `string` | - |
| `mtype` | `string` | - |
| `entries` | [`List of Entry`](#entry) | - |

##### Example (as JSON)

```json
{
  "feedUrl": "http://ramrojob.com/feed",
  "title": "Ramro Job",
  "link": "http://ramrojob.com",
  "author": "",
  "description": "...your pathway to success",
  "type": "rss20",
  "entries": [
    {
      "title": "Monitoring and Evaluation Specialist Wanted at GRM International",
      "link": "http://ramrojob.com/job/2013/05/12/monitoring-and-evaluation-specialist-wanted-at-grm-international.html",
      "author": "Bandana Aryal",
      "publishedDate": "Sun, 12 May 2013 01:10:24 -0700",
      "contentSnippet": "Key Responsibilities Under direction of the Team Leader, responsible for the design and roll out of programme M&#38;E plan, ...",
      "content": "<p><strong>Key Responsibilities</strong></p>\n<ul>\n<li>Under direction of the Team Leader, responsible for the design and roll out of programme M&amp;E plan, including design of the logframe and key performance indicators.</li>\n<li>Track programme progress against indicators and ensure early identification of any areas requiring remedial action.</li>\n<li>Carry out site visits and provide M&amp;E support and training for local partners.</li>\n<li>Harmonise programme monitoring indicators and systems with national M&amp;E systems.</li>\n<li>Promote use of data to inform decision making and link evidence-based approaches to achievement of results.</li>\n<li>Support operations research and specialised studies, such as client satisfaction, cost-effectiveness, and impact evaluation.</li>\n<li>Solicit and manage local data collection and research teams, as needed.</li>\n<li>Contribute to the preparation of regular progress reports, technical deliverables, presentations, and annual work plans.</li>\n</ul>\n<p><strong>Qualifications</strong></p>\n<ul>\n<li>Seven or more years of experience monitoring and evaluating reproductive health and family planning programmes, including promoting use of data for decision-making.</li>\n<li>Strong technical grasp of relevant health issues: sexual and reproductive health; family planning; maternal, new-born, and child health; HIV and AIDS; and health equity.</li>\n<li>Understanding of health market dynamics and the health system in Nepal.</li>\n<li>Demonstrated experience working with government, private sector, and nongovernmental health sector partners in Nepal, at national and decentralised levels.</li>\n<li>Experience supporting DFID, European Union, USAID, World Bank, or other donor-funded or government health programmes.</li>\n<li>Strong quantitative and qualitative research and analysis skills.</li>\n<li>Demonstrated experience with computerised management information systems, databases, MS Office, and other relevant skills.</li>\n<li>Ability to graphically present data in ways that engage and influence target audiences.</li>\n<li>Knowledge of in-country and international guidelines pertaining to research ethics.</li>\n<li>Strong personal qualities, including integrity, commitment to excellence, equality, openness, inclusiveness, and collegiality.</li>\n<li>Excellent written and spoken English required, local languages are a distinct advantage.</li>\n<li>Advanced degree/s in relevant discipline preferred.</li>\n<li>Nepali nationals strongly encouraged to apply.</li>\n</ul>\n<p>The post <a href=\"http://ramrojob.com/job/2013/05/12/monitoring-and-evaluation-specialist-wanted-at-grm-international.html\">Monitoring and Evaluation Specialist Wanted at GRM International</a> appeared first on <a href=\"http://ramrojob.com\">Ramro Job</a>.</p>",
      "categories": [
        "Uncategorized"
      ]
    },
    {
      "title": "Director of Finance and Admin Wanted at Abt Associates",
      "link": "http://ramrojob.com/job/2013/05/12/director-of-finance-and-admin-wanted-at-abt-associates.html",
      "author": "Bandana Aryal",
      "publishedDate": "Sun, 12 May 2013 01:02:28 -0700",
      "contentSnippet": "Job Responsibilities: Abt Associates seeks a Director of Finance and Administration for an upcoming DFID-funded family planning ...",
      "content": "<p><strong>Job Responsibilities:</strong></p>\n<p>Abt Associates seeks a Director of Finance and Administration for an upcoming DFID-funded family planning program in Nepal. The initiative will work with the Ministry of Health and Population to increase use of modern high-quality family planning methods by the most vulnerable and excluded women by supply innovative and high quality family planning services. The program will also work with the Ministry of Health and Population to ensure better choices and availabilites of reproductive health commodities.</p>\n<p>The Director of Finance and Administration will be responsible for the management of the contract, procurement, subcontracting, financial management and reporting, and general administrative support of the program. S/he will develop and track budgets, manage payroll and vendor relations, and control all financial transactions and reporting, both for the client and for Abt Associates headquarters.</p>\n<p>Specific responsibilities will include:</p>\n<ul>\n<li>Ensure compliance with terms and references in the contract;</li>\n<li>Develop and implement financial and administrative policies and procedures that meet project requirements and donor regulations;</li>\n<li>Create and maintain financial reporting and tracking systems, and provide financial performance updates on project activities;</li>\n<li>Prepare budgets and revenue plans for project programming and corporate reporting;</li>\n<li>Oversee financial and HR administration of project (purchase requisitions, consulting agreements, vendor invoices, client invoices, payroll etc.);</li>\n<li>Manage vendors and subcontractors in compliance with Abt and DfID policies and regulations;</li>\n<li>Supervise all financial and administrative staff;</li>\n<li>Provide training to field staff on project procedures as well as building skill-levels of project staff in the area of finance, administration, and project management.</li>\n</ul>\n<p><strong>Skills Prerequisites:</strong></p>\n<ul>\n<li>Bachelor�s Degree (minimum) or master�s degree (preferred) in Business, Finance, Accounting or other relevant field;</li>\n<li>10 years of experience in administration, project management and/or financial management;</li>\n<li>5 years of experience working with international donors in a development setting;</li>\n<li>Experience with DfID contracts desirable;</li>\n<li>Strong analytical and computer skills, with emphasis on budgeting and financial analysis;</li>\n<li>Excellent inter-personal, communication and organizational skills;</li>\n<li>Capabilities in Nepali or other South Asian languages are desirable.</li>\n</ul>\n<p>The post <a href=\"http://ramrojob.com/job/2013/05/12/director-of-finance-and-admin-wanted-at-abt-associates.html\">Director of Finance and Admin Wanted at Abt Associates</a> appeared first on <a href=\"http://ramrojob.com\">Ramro Job</a>.</p>",
      "categories": [
        "Uncategorized"
      ]
    },
    {
      "title": "Technical Director Wanted at Family Planning Nepal",
      "link": "http://ramrojob.com/job/2013/05/12/technical-director-wanted-at-family-planning-nepal.html",
      "author": "Bandana Aryal",
      "publishedDate": "Sun, 12 May 2013 00:57:03 -0700",
      "contentSnippet": "Skills Prerequisites: Masters Degree (minimum) in Public Health, Business Administration or related relevant discipline Ten ...",
      "content": "<p><strong>Skills Prerequisites:</strong></p>\n<ul>\n<li>Masters Degree (minimum) in Public Health, Business Administration or related relevant discipline</li>\n<li>Ten years (10) of relevant professional experience, including sales or marketing, and strong business acumen in areas of business process and analysis would be highly valued</li>\n<li>Eight (8) years experience working in health sector projects or initiatives involving multiple stakeholder groups, including NGOs and the private health sector</li>\n<li>Successful prior experience in social marketing or franchising</li>\n<li>Proven track record of building and sustaining effective partnerships, advocating effectively and communicating to various constituencies</li>\n<li>Ability to coordinate in a dynamic environment</li>\n<li>Substantial experience in building capacity in the non-state/private sector</li>\n<li>Ability to independently plan and execute complex tasks while addressing daily management details and remaining organized and focused on long-term deadlines and strategies</li>\n<li>Solid professional reputation and strong, demonstrated interpersonal skills</li>\n<li>Professional working experience in Nepal desirable</li>\n<li>Fluency in Nepali desirable</li>\n<li>Excellent written and oral presentation skills in English</li>\n</ul>\n<p>The post <a href=\"http://ramrojob.com/job/2013/05/12/technical-director-wanted-at-family-planning-nepal.html\">Technical Director Wanted at Family Planning Nepal</a> appeared first on <a href=\"http://ramrojob.com\">Ramro Job</a>.</p>",
      "categories": [
        "Uncategorized"
      ]
    },
    {
      "title": "Monitoring and Evaluation Analyst Wanted at UN Women",
      "link": "http://ramrojob.com/job/2013/05/12/monitoring-and-evaluation-analyst-wanted-at-un-women.html",
      "author": "Bandana Aryal",
      "publishedDate": "Sun, 12 May 2013 00:46:37 -0700",
      "contentSnippet": "Core Competencies Knowledge of current practices in the area of monitoring and evaluation, knowledge management Promotes the ...",
      "content": "<p><b>Core Competencies</b></p>\n<ul>\n<li>Knowledge of current practices in the area of monitoring and evaluation, knowledge management</li>\n<li>Promotes the vision, mission, and strategic goals of UN Women;</li>\n<li>Displays cultural, gender, religion, race, nationality and age sensitivity and adaptability</li>\n<li>Fostering innovation and empowerment</li>\n<li>Working in teams at all levels</li>\n<li>Communicating information and ideas/knowledge sharing</li>\n<li>Analytical and strategic thinking/results orientation/commitment to Excellence</li>\n</ul>\n<p><span style=\"text-decoration:underline\"><strong>Qualifications and Experience:</strong></span></p>\n<ul>\n<li>Master�s Degree in Economics, Management, Rural Development, Social Sciences, or related field. Additional certification in statistics, MIS management and Monitoring and Evaluation will be considered as an asset.</li>\n<li>Two years of relevant professional experience in the field of rights based monitoring and evaluation;</li>\n<li>Experience in the management of gender equality and women�s empowerment programmes or analytic work in gender and development, gender analysis and/or human rights;</li>\n<li> Good knowledge of rights-based approach and result-based management.</li>\n<li> Experience related to UN Women�s mandate and activities would be an added advantage;</li>\n<li> Sound knowledge of international standards on human rights, women�s rights and related instruments;</li>\n<li>A proven ability to liaise with a myriad of stakeholders and partners, including government, civil society, international organizations and grassroots organizations</li>\n</ul>\n<p>The post <a href=\"http://ramrojob.com/job/2013/05/12/monitoring-and-evaluation-analyst-wanted-at-un-women.html\">Monitoring and Evaluation Analyst Wanted at UN Women</a> appeared first on <a href=\"http://ramrojob.com\">Ramro Job</a>.</p>",
      "categories": [
        "The Himalayan Times"
      ]
    }
  ]
}
```

#### Entry

##### Class Name

`Entry`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `title` | `string` | - |
| `link` | `string` | - |
| `author` | `string` | - |
| `published_date` | `string` | - |
| `content_snippet` | `string` | - |
| `content` | `string` | - |
| `categories` | `List of string` | - |

##### Example (as JSON)

```json
{
  "title": "Monitoring and Evaluation Specialist Wanted at GRM International",
  "link": "http://ramrojob.com/job/2013/05/12/monitoring-and-evaluation-specialist-wanted-at-grm-international.html",
  "author": "Bandana Aryal",
  "publishedDate": "Sun, 12 May 2013 01:10:24 -0700",
  "contentSnippet": "Key Responsibilities Under direction of the Team Leader, responsible for the design and roll out of programme M&#38;E plan, ...",
  "content": "<p><strong>Key Responsibilities</strong></p>\n<ul>\n<li>Under direction of the Team Leader, responsible for the design and roll out of programme M&amp;E plan, including design of the logframe and key performance indicators.</li>\n<li>Track programme progress against indicators and ensure early identification of any areas requiring remedial action.</li>\n<li>Carry out site visits and provide M&amp;E support and training for local partners.</li>\n<li>Harmonise programme monitoring indicators and systems with national M&amp;E systems.</li>\n<li>Promote use of data to inform decision making and link evidence-based approaches to achievement of results.</li>\n<li>Support operations research and specialised studies, such as client satisfaction, cost-effectiveness, and impact evaluation.</li>\n<li>Solicit and manage local data collection and research teams, as needed.</li>\n<li>Contribute to the preparation of regular progress reports, technical deliverables, presentations, and annual work plans.</li>\n</ul>\n<p><strong>Qualifications</strong></p>\n<ul>\n<li>Seven or more years of experience monitoring and evaluating reproductive health and family planning programmes, including promoting use of data for decision-making.</li>\n<li>Strong technical grasp of relevant health issues: sexual and reproductive health; family planning; maternal, new-born, and child health; HIV and AIDS; and health equity.</li>\n<li>Understanding of health market dynamics and the health system in Nepal.</li>\n<li>Demonstrated experience working with government, private sector, and nongovernmental health sector partners in Nepal, at national and decentralised levels.</li>\n<li>Experience supporting DFID, European Union, USAID, World Bank, or other donor-funded or government health programmes.</li>\n<li>Strong quantitative and qualitative research and analysis skills.</li>\n<li>Demonstrated experience with computerised management information systems, databases, MS Office, and other relevant skills.</li>\n<li>Ability to graphically present data in ways that engage and influence target audiences.</li>\n<li>Knowledge of in-country and international guidelines pertaining to research ethics.</li>\n<li>Strong personal qualities, including integrity, commitment to excellence, equality, openness, inclusiveness, and collegiality.</li>\n<li>Excellent written and spoken English required, local languages are a distinct advantage.</li>\n<li>Advanced degree/s in relevant discipline preferred.</li>\n<li>Nepali nationals strongly encouraged to apply.</li>\n</ul>\n<p>The post <a href=\"http://ramrojob.com/job/2013/05/12/monitoring-and-evaluation-specialist-wanted-at-grm-international.html\">Monitoring and Evaluation Specialist Wanted at GRM International</a> appeared first on <a href=\"http://ramrojob.com\">Ramro Job</a>.</p>",
  "categories": [
    "Uncategorized"
  ]
}
```

#### DateAsOptional

##### Class Name

`DateAsOptional`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date` | `date` | Optional | - |

##### Example (as JSON)

```json
{
  "date": null
}
```

#### AddPrecisionInException

##### Class Name

`AddPrecisionInException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `float` |  | - |
| `value_1` | `float` | Optional | - |

##### Example (as JSON)

```json
{
  "value": 1.23
}
```

#### AddUuidInGlobalException

##### Class Name

`AddUuidInGlobalException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `uuid|string` |  | - |
| `value_1` | `uuid|string` | Optional | - |

##### Example (as JSON)

```json
{
  "value": "123e4567-e89b-12d3-a456-426655440000"
}
```

#### AddRfc1123DatetimeInGlobalException

##### Class Name

`AddRfc1123DatetimeInGlobalException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | `datetime` |  | - |
| `date_time_1` | `datetime` | Optional | - |

##### Example (as JSON)

```json
{
  "dateTime": "Sun, 06 Nov 1994 08:49:37 GMT"
}
```

#### AddNumberInException

##### Class Name

`AddNumberInException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `int` |  | - |
| `value_1` | `int` | Optional | - |

##### Example (as JSON)

```json
{
  "value": 1
}
```

#### AddDynamicInException

##### Class Name

`AddDynamicInException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `object` |  | - |
| `value_1` | `object` | Optional | - |

##### Example (as JSON)

```json
{
  "value": " {\r\n\t\t\t\"value\" : \"test\"\r\n\t\t}"
}
```

#### AddRfc3339DatetimeInGlobalException

##### Class Name

`AddRfc3339DatetimeInGlobalException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | `datetime` |  | - |
| `date_time_1` | `datetime` | Optional | - |

##### Example (as JSON)

```json
{
  "dateTime": "2016-03-13T12:52:32.123Z",
  "dateTime1": null
}
```

#### AddBooleanInGlobalException

##### Class Name

`AddBooleanInGlobalException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `bool` |  | - |
| `value_1` | `bool` | Optional | - |

##### Example (as JSON)

```json
{
  "value": false,
  "value1": null
}
```

#### AddDateInGlobalException

##### Class Name

`AddDateInGlobalException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `date` |  | - |
| `value_1` | `date` | Optional | - |

##### Example (as JSON)

```json
{
  "value": "1994-02-13"
}
```

#### AddStringInGlobalException

##### Class Name

`AddStringInGlobalException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `string` |  | - |
| `value_1` | `string` | Optional | - |

##### Example (as JSON)

```json
{
  "value": "test"
}
```

#### AddUnixTimeStampInGlobalException

##### Class Name

`AddUnixTimeStampInGlobalException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | `datetime` |  | - |
| `date_time_1` | `datetime` | Optional | - |

##### Example (as JSON)

```json
{
  "dateTime": 1484719381
}
```

#### AddLongInGlobalException

##### Class Name

`AddLongInGlobalException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `long|int` |  | - |
| `value_1` | `long|int` | Optional | - |

##### Example (as JSON)

```json
{
  "value": 123123
}
```

### Enumerations

* [Days](#days)
* [SuiteCode](#suitecode)
* [ParamFormat](#paramformat)
* [Type](#type)
* [LanguageEnum](#languageenum)
* [Team](#team)
* [TeamInteger](#teaminteger)

#### Days

A string enum representing days of the week

##### Class Name

`Days`

##### Fields

| Name | Description |
|  --- | --- |
| `SUNDAY` | - |
| `MONDAY` | - |
| `TUESDAY` | - |
| `WEDNESDAY_` | - |
| `THURSDAY` | - |
| `FRI_DAY` | - |
| `SATURDAY` | - |

#### SuiteCode

A integer based enum representing a Suite in a game of cards

##### Class Name

`SuiteCode`

##### Fields

| Name | Description |
|  --- | --- |
| `HEARTS` | - |
| `SPADES` | - |
| `CLUBS` | - |
| `DIAMONDS` | - |

#### ParamFormat

##### Class Name

`ParamFormat`

##### Fields

| Name | Description |
|  --- | --- |
| `TEMPLATE` | - |
| `FORM` | - |
| `BODY` | - |
| `HEADER` | - |
| `QUERY` | - |

#### Type

##### Class Name

`Type`

##### Fields

| Name | Description |
|  --- | --- |
| `LONG` | - |
| `NUMBER` | - |
| `PRECISION` | - |
| `BOOLEAN` | - |
| `DATETIME` | - |
| `DATE` | - |
| `STRING` | - |

#### LanguageEnum

##### Class Name

`LanguageEnum`

##### Fields

| Name | Description |
|  --- | --- |
| `EN` | - |
| `DZ` | - |
| `NL` | - |

#### Team

##### Class Name

`Team`

##### Fields

| Name | Description |
|  --- | --- |
| `CODEGEN` | - |
| `CGAAS` | - |
| `UX` | - |
| `QA` | - |

#### TeamInteger

##### Class Name

`TeamInteger`

##### Fields

| Name | Description |
|  --- | --- |
| `CODEGEN` | - |
| `CGAAS` | - |
| `UX` | - |
| `QA` | - |

### Exceptions

* [LocalTestException](#localtestexception)
* [GlobalTestException](#globaltestexception)
* [NestedModelException](#nestedmodelexception)
* [Rfc1123Exception](#rfc1123exception)
* [UnixTimeStampException](#unixtimestampexception)
* [ExceptionWithRfc3339DateTimeException](#exceptionwithrfc3339datetimeexception)
* [ExceptionWithDateException](#exceptionwithdateexception)
* [ExceptionWithUUIDException](#exceptionwithuuidexception)
* [ExceptionWithDynamicException](#exceptionwithdynamicexception)
* [ExceptionWithPrecisionException](#exceptionwithprecisionexception)
* [ExceptionWithBooleanException](#exceptionwithbooleanexception)
* [ExceptionWithLongException](#exceptionwithlongexception)
* [ExceptionWithNumberException](#exceptionwithnumberexception)
* [ExceptionWithStringException](#exceptionwithstringexception)
* [CustomErrorResponseException](#customerrorresponseexception)
* [SendUuidInModelAsException](#senduuidinmodelasexception)
* [SendPrecisionInModelAsException](#sendprecisioninmodelasexception)
* [SendNumberInModelAsException](#sendnumberinmodelasexception)
* [SendLongInModelAsException](#sendlonginmodelasexception)
* [SendStringInModelAsException](#sendstringinmodelasexception)
* [SendDynamicInModelAsException](#senddynamicinmodelasexception)
* [SendDateInModelAsException](#senddateinmodelasexception)
* [SendUnixTimeStampInModelAsException](#sendunixtimestampinmodelasexception)
* [SendRfc3339InModelAsException](#sendrfc3339inmodelasexception)
* [SendRfc1123InModelAsException](#sendrfc1123inmodelasexception)
* [SendBooleanInModelAsException](#sendbooleaninmodelasexception)
* [ComplexObjectInException](#complexobjectinexception)
* [EnumInException](#enuminexception)

#### LocalTestException

To test specific local exceptions.

##### Class Name

`LocalTestException`

##### Inherits From

[`GlobalTestException`](#globaltestexception)

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `secret_message_for_endpoint` | `string` | Represents the specific endpoint info |

##### Example (as JSON)

```json
{
  "SecretMessageForEndpoint": "SecretMessageForEndpoint6",
  "ServerMessage": "ServerMessage6",
  "ServerCode": 170
}
```

#### GlobalTestException

To test specific global exceptions.

##### Class Name

`GlobalTestException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `server_message` | `string` | Represents the server's exception message |
| `server_code` | `int` | Represents the server's error code |

##### Example (as JSON)

```json
{
  "ServerMessage": "ServerMessage6",
  "ServerCode": 170
}
```

#### NestedModelException

##### Class Name

`NestedModelException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `server_message` | `string` | - |
| `server_code` | `string` | - |
| `model` | [`Validate`](#validate) | - |

##### Example (as JSON)

```json
{
  "ServerMessage": "ServerMessage6",
  "ServerCode": "ServerCode0",
  "model": {
    "field": "field4",
    "name": "name2",
    "address": null
  }
}
```

#### Rfc1123Exception

##### Class Name

`Rfc1123Exception`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | `datetime` |  | - |
| `date_time_1` | `datetime` | Optional | - |

##### Example (as JSON)

```json
{
  "dateTime": "Sun, 06 Nov 1994 08:49:37 GMT"
}
```

#### UnixTimeStampException

##### Class Name

`UnixTimeStampException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | `datetime` |  | - |
| `date_time_1` | `datetime` | Optional | - |

##### Example (as JSON)

```json
{
  "dateTime": 1484719381
}
```

#### ExceptionWithRfc3339DateTimeException

##### Class Name

`ExceptionWithRfc3339DateTimeException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `date_time` | `datetime` |  | - |
| `date_time_1` | `datetime` | Optional | - |

##### Example (as JSON)

```json
{
  "dateTime": "2016-03-13T12:52:32.123Z",
  "dateTime1": null
}
```

#### ExceptionWithDateException

##### Class Name

`ExceptionWithDateException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `date` |  | - |
| `value_1` | `date` | Optional | - |

##### Example (as JSON)

```json
{
  "value": "1994-02-13"
}
```

#### ExceptionWithUUIDException

##### Class Name

`ExceptionWithUUIDException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `uuid|string` |  | - |
| `value_1` | `uuid|string` | Optional | - |

##### Example (as JSON)

```json
{
  "value": "123e4567-e89b-12d3-a456-426655440000"
}
```

#### ExceptionWithDynamicException

##### Class Name

`ExceptionWithDynamicException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `object` |  | - |
| `value_1` | `object` | Optional | - |

##### Example (as JSON)

```json
{
  "value": "{\n  \"value\" : \"test\"\n}"
}
```

#### ExceptionWithPrecisionException

##### Class Name

`ExceptionWithPrecisionException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `float` |  | - |
| `value_1` | `float` | Optional | - |

##### Example (as JSON)

```json
{
  "value": 1.23
}
```

#### ExceptionWithBooleanException

##### Class Name

`ExceptionWithBooleanException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `bool` |  | - |
| `value_1` | `bool` | Optional | - |

##### Example (as JSON)

```json
{
  "value": true
}
```

#### ExceptionWithLongException

##### Class Name

`ExceptionWithLongException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `long|int` |  | - |
| `value_1` | `long|int` | Optional | - |

##### Example (as JSON)

```json
{
  "value": 12312312
}
```

#### ExceptionWithNumberException

##### Class Name

`ExceptionWithNumberException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `int` |  | - |
| `value_1` | `int` | Optional | - |

##### Example (as JSON)

```json
{
  "value": 1
}
```

#### ExceptionWithStringException

##### Class Name

`ExceptionWithStringException`

##### Fields

| Name | Type | Tags | Description |
|  --- | --- | --- | --- |
| `value` | `string` |  | - |
| `value_1` | `string` | Optional | - |

##### Example (as JSON)

```json
{
  "value": "test"
}
```

#### CustomErrorResponseException

##### Class Name

`CustomErrorResponseException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `error_description` | `string` | - |
| `caught` | `string` | - |
| `exception` | `string` | - |
| `inner_exception` | `string` | - |

##### Example (as JSON)

```json
{
  "error description": null,
  "caught": "Error in CatchInner caused by calling the ThrowInner method.",
  "Exception": "In catch block of Main method.",
  "Inner Exception": "AppException: Exception in ThrowInner method."
}
```

#### SendUuidInModelAsException

##### Class Name

`SendUuidInModelAsException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `body` | [`AddUuidInGlobalException`](#adduuidinglobalexception) | - |

##### Example (as JSON)

```json
{
  "body": {
    "value": "123e4567-e89b-12d3-a456-426655440000"
  }
}
```

#### SendPrecisionInModelAsException

##### Class Name

`SendPrecisionInModelAsException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `body` | [`AddPrecisionInException`](#addprecisioninexception) | - |

##### Example (as JSON)

```json
{
  "body": {
    "value": 1.23
  }
}
```

#### SendNumberInModelAsException

##### Class Name

`SendNumberInModelAsException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `body` | [`AddNumberInException`](#addnumberinexception) | - |

##### Example (as JSON)

```json
{
  "body": {
    "value": 1
  }
}
```

#### SendLongInModelAsException

##### Class Name

`SendLongInModelAsException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `body` | [`AddLongInGlobalException`](#addlonginglobalexception) | - |

##### Example (as JSON)

```json
{
  "body": {
    "value": 123123
  }
}
```

#### SendStringInModelAsException

##### Class Name

`SendStringInModelAsException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `body` | [`AddStringInGlobalException`](#addstringinglobalexception) | - |

##### Example (as JSON)

```json
{
  "body": {
    "value": "test"
  }
}
```

#### SendDynamicInModelAsException

##### Class Name

`SendDynamicInModelAsException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `body` | [`AddDynamicInException`](#adddynamicinexception) | - |

##### Example (as JSON)

```json
{
  "body": {
    "value": " {\r\n\t\t\t\"value\" : \"test\"\r\n\t\t}"
  }
}
```

#### SendDateInModelAsException

##### Class Name

`SendDateInModelAsException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `body` | [`AddDateInGlobalException`](#adddateinglobalexception) | - |

##### Example (as JSON)

```json
{
  "body": {
    "value": "1994-02-13"
  }
}
```

#### SendUnixTimeStampInModelAsException

##### Class Name

`SendUnixTimeStampInModelAsException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `body` | [`AddUnixTimeStampInGlobalException`](#addunixtimestampinglobalexception) | - |

##### Example (as JSON)

```json
{
  "body": {
    "dateTime": 1484719381
  }
}
```

#### SendRfc3339InModelAsException

##### Class Name

`SendRfc3339InModelAsException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `body` | [`AddRfc3339DatetimeInGlobalException`](#addrfc3339datetimeinglobalexception) | - |

##### Example (as JSON)

```json
{
  "body": {
    "dateTime": "2016-03-13T12:52:32.123Z",
    "dateTime1": null
  }
}
```

#### SendRfc1123InModelAsException

##### Class Name

`SendRfc1123InModelAsException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `body` | [`AddRfc1123DatetimeInGlobalException`](#addrfc1123datetimeinglobalexception) | - |

##### Example (as JSON)

```json
{
  "body": {
    "dateTime": "Sun, 06 Nov 1994 08:49:37 GMT"
  }
}
```

#### SendBooleanInModelAsException

##### Class Name

`SendBooleanInModelAsException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `body` | [`AddBooleanInGlobalException`](#addbooleaninglobalexception) | - |

##### Example (as JSON)

```json
{
  "body": {
    "value": false,
    "value1": null
  }
}
```

#### ComplexObjectInException

##### Class Name

`ComplexObjectInException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `body` | [`Complex3`](#complex3) | - |

##### Example (as JSON)

```json
{
  "body": {
    "documentId": "099cceda-38a8-4b01-87b9-a8f2007675d6",
    "signers": [
      {
        "id": "1bef97d1-0704-4eb2-a490-a8f2007675db",
        "url": "https://sign-test.idfy.io/start?jwt=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzM4NCJ9. .Dyy2RSeR6dmU8qxOEi-2gEX3Gg7wry6JhkZIWOuADDdu5jJWidQLcxfJn_qAHNpb",
        "links": [],
        "externalSignerId": "uoiahsd321982983jhrmnec2wsadm32",
        "redirectSettings": {
          "redirectMode": "donot_redirect"
        },
        "signatureType": {
          "mechanism": "pkisignature",
          "onEacceptUseHandWrittenSignature": false
        },
        "ui": {
          "dialogs": {
            "before": {
              "useCheckBox": false,
              "title": "Info",
              "message": "Please read the contract on the next pages carefully. Pay some extra attention to paragraph 5."
            }
          },
          "language": "EN",
          "styling": {
            "colorTheme": "Pink",
            "spinner": "Cubes"
          }
        },
        "tags": [],
        "order": 0,
        "required": false
      }
    ],
    "status": {
      "documentStatus": "unsigned",
      "completedPackages": [],
      "attachmentPackages": {}
    },
    "title": "Test document",
    "description": "This is an important document",
    "externalId": "ae7b9ca7-3839-4e0d-a070-9f14bffbbf55",
    "dataToSign": {
      "fileName": "sample.txt",
      "convertToPDF": false
    },
    "contactDetails": {
      "email": "test@test.com",
      "url": "https://idfy.io"
    },
    "advanced": {
      "tags": [
        "develop",
        "fun_with_documents"
      ],
      "attachments": 0,
      "requiredSignatures": 0,
      "getSocialSecurityNumber": false,
      "timeToLive": {
        "deadline": "2018-06-29T14:57:25Z",
        "deleteAfterHours": 1
      }
    }
  }
}
```

#### EnumInException

##### Class Name

`EnumInException`

##### Fields

| Name | Type | Description |
|  --- | --- | --- |
| `param` | [`ParamFormat`](#paramformat) | - |
| `mtype` | [`Type`](#type) | - |

##### Example (as JSON)

```json
{
  "param": "Template",
  "type": "Long"
}
```